@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 /*********************************************************************************
@@ -1273,7 +1273,7 @@ static void GenDBCC()
         // generate jump table
         gen_opjumptable(base + (cond << 8));
         // generate label & declarations
-        start_op(base + (cond << 8), GEN_RES);
+        start_op(base + (cond << 8), cond==COND_TR ? 0 : GEN_RES);
         
         if (cond != COND_TR)
         {
@@ -1501,7 +1501,7 @@ static void GenLogicaD(char op)
 
     if (current_size == SIZE_LONG)
     {
-        if (is_ea_memory(current_ea)) current_cycle += 2;
+        if (!is_ea_memory(current_ea)) current_cycle += 2;
         else current_cycle += 4;
     }
 
@@ -2030,7 +2030,7 @@ static void GenArithaD(char op)
 
     if (current_size == SIZE_LONG)
     {
-        if ((is_ea_memory(current_ea)) || (op == ' ')) current_cycle += 2;
+        if (!is_ea_memory(current_ea)) current_cycle += 2;
         else current_cycle += 4;
     }
 
@@ -2095,7 +2095,7 @@ static void GenArithA(char op)
     else
         start_all(GEN_ALL);
 
-    if ((current_size == SIZE_WORD) && (op != ' ') && (!is_ea_memory(current_ea))) current_cycle += 2;
+    if ((op != ' ') && ((current_size == SIZE_WORD) || (is_ea_memory(current_ea)))) current_cycle += 2;
 
     // read src
     _ea_calc(current_ea, current_op->reg_sft);
@@ -2870,10 +2870,11 @@ static void GenASRD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -2957,10 +2958,11 @@ static void GenLSRD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3028,10 +3030,11 @@ static void GenROXRD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3095,10 +3098,11 @@ static void GenRORD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3148,10 +3152,11 @@ static void GenASLD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3232,10 +3237,11 @@ static void GenLSLD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3311,10 +3317,11 @@ static void GenROXLD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
@@ -3378,10 +3385,11 @@ static void GenROLD()
 //    u32 base = get_current_opcode_base();
 
     current_ea = EA_DREG;               // dst = Dx
-    if (current_size == SIZE_LONG) current_cycle += 2;
 
     start_all(GEN_RES | GEN_SRC);
 
+    if (current_size == SIZE_LONG) current_cycle += 2;
+
     wf_op("\tu32 sft;\n");
     wf_op("\n");
     wf_op("\tsft = CPU->D[(Opcode >> %d) & 7] & 0x3F;\n", current_op->reg2_sft);
