@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <Carbon/Carbon.h>
@@ -47,5 +47,3 @@ struct _YuiAction {
 
 extern YuiAction key_config[];
 */
-
-extern const char * key_names[];
