@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <string.h>
@@ -452,6 +452,11 @@ int ISOCDReadSectorFAD(u32 FAD, void *buffer) {
                break;
            }
         }
+	if (i == 100) {
+		// FIXME: Placeholder message; what's the actual error?  --AC
+		CDLOG("Warning: Sector not found");
+		return 0;
+	}
 
 	if ((sector * bytesPerSector) >= isofilesize) {
 		CDLOG("Warning: Trying to read beyond end of CD image! (sector: %d)\n", sector);
