@@ -14,12 +14,13 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <stdlib.h>
 #include "cheat.h"
 #include "memory.h"
+#include "sh2core.h"
 
 cheatlist_struct *cheatlist=NULL;
 int numcheats=0;
@@ -78,8 +79,8 @@ int CheatAddCode(int type, u32 addr, u32 val)
 
 int CheatAddARCode(const char *code)
 {
-   u32 addr;
-   u16 val;
+   unsigned long addr;
+   unsigned short val;
    sscanf(code, "%08lX %04hX", &addr, &val);
    switch (addr >> 28)
    {
@@ -180,8 +181,8 @@ int CheatRemoveCodeByIndex(int i)
 
 int CheatRemoveARCode(const char *code)
 {
-   u32 addr;
-   u16 val;
+   unsigned long addr;
+   unsigned short val;
    sscanf(code, "%08lX %04hX", &addr, &val);
 
    switch (addr >> 28)
@@ -240,16 +241,19 @@ void CheatDoPatches(void)
             if (cheatlist[i].enable == 0)
                continue;
             MappedMemoryWriteByte(cheatlist[i].addr, (u8)cheatlist[i].val);
+            SH2WriteNotify(cheatlist[i].addr, 1);
             break;
          case CHEATTYPE_WORDWRITE:
             if (cheatlist[i].enable == 0)
                continue;
             MappedMemoryWriteWord(cheatlist[i].addr, (u16)cheatlist[i].val);
+            SH2WriteNotify(cheatlist[i].addr, 2);
             break;
          case CHEATTYPE_LONGWRITE:
             if (cheatlist[i].enable == 0)
                continue;
             MappedMemoryWriteLong(cheatlist[i].addr, cheatlist[i].val);
+            SH2WriteNotify(cheatlist[i].addr, 4);
             break;            
       }
    }
