@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef CORE_H
@@ -107,18 +107,20 @@ typedef struct {
 } IOCheck_struct;
 
 static INLINE void ywrite(IOCheck_struct * check, void * ptr, size_t size, size_t nmemb, FILE * stream) {
-   check->done += fwrite(ptr, size, nmemb, stream);
-   check->size += size;
+   check->done += (unsigned int)fwrite(ptr, size, nmemb, stream);
+   check->size += (unsigned int)nmemb;
 }
 
 static INLINE void yread(IOCheck_struct * check, void * ptr, size_t size, size_t nmemb, FILE * stream) {
-   check->done += fread(ptr, size, nmemb, stream);
-   check->size += size;
+   check->done += (unsigned int)fread(ptr, size, nmemb, stream);
+   check->size += (unsigned int)nmemb;
 }
 
 static INLINE int StateWriteHeader(FILE *fp, const char *name, int version) {
    IOCheck_struct check;
    fprintf(fp, "%s", name);
+   check.done = 0;
+   check.size = 0;
    ywrite(&check, (void *)&version, sizeof(version), 1, fp);
    ywrite(&check, (void *)&version, sizeof(version), 1, fp); // place holder for size
    return (check.done == check.size) ? ftell(fp) : -1;
@@ -129,6 +131,8 @@ static INLINE int StateFinishHeader(FILE *fp, int offset) {
    int size = 0;
    size = ftell(fp) - offset;
    fseek(fp, offset - 4, SEEK_SET);
+   check.done = 0;
+   check.size = 0;
    ywrite(&check, (void *)&size, sizeof(size), 1, fp); // write true size
    fseek(fp, 0, SEEK_END);
    return (check.done == check.size) ? (size + 12) : -1;
@@ -194,11 +198,20 @@ static INLINE int StateCheckRetrieveHeader(FILE *fp, const char *name, int *vers
 #define USED_IF_SMPC_DEBUG __attribute ((unused))
 #endif
 
+/* LIKELY(x) indicates that x is likely to be true (nonzero);
+ * UNLIKELY(x) indicates that x is likely to be false (zero).
+ * Use like: "if (UNLIKELY(a < b)) {...}" */
+#define LIKELY(x) (__builtin_expect(!!(x), 1))
+#define UNLIKELY(x) (__builtin_expect(!!(x), 0))
+
 #else
 
 #define UNUSED
 #define USED_IF_DEBUG
 #define USED_IF_SMPC_DEBUG
+#define LIKELY(x) (x)
+#define UNLIKELY(x) (x)
+
 #endif
 
 #endif
