@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include "gtkglwidget.h"
@@ -46,7 +46,6 @@ void yui_gl_draw(YuiGl * glxarea) {
 #else
 	int buf_width, buf_height;
 	GdkPixbuf * pixbuf, * scaledpixbuf;
-	GdkRectangle rect = { 0, 0, GTK_WIDGET(glxarea)->allocation.width, GTK_WIDGET(glxarea)->allocation.height };
 	
 	VIDSoftGetScreenSize( &buf_width, &buf_height );
 	glxarea->pixels_width = GTK_WIDGET(glxarea)->allocation.width;
@@ -119,8 +118,8 @@ gboolean gonna_hide(gpointer data) {
 	beforehiding--;
 
 	if (beforehiding == 0) {
-		static unsigned char source_data[] = { 0 };
-		static unsigned char mask_data[] = { 0 };
+		static char source_data[] = { 0 };
+		static char mask_data[] = { 0 };
 
 		GdkCursor *cursor;
  		GdkPixmap *source, *mask;
@@ -147,7 +146,7 @@ int oldx = 0;
 int oldy = 0;
 
 static gboolean yui_gl_hide_cursor(GtkWidget * widget, GdkEventMotion * event, gpointer user_data) {
-	if (*((u8 *) padbits) == PERMOUSE) {
+	if (PerGetId(padbits) == PERMOUSE) {
 		int x = event->x;
 		int y = event->y;
 		double speed = g_key_file_get_double(keyfile, "General", "MouseSpeed", NULL);
@@ -168,7 +167,7 @@ static gboolean yui_gl_hide_cursor(GtkWidget * widget, GdkEventMotion * event, g
 }
 
 static gboolean yui_gl_button_press(GtkWidget * widget, GdkEventButton * event, gpointer user_data) {
-	if (*((u8 *) padbits) == PERMOUSE) {
+	if (PerGetId(padbits) == PERMOUSE) {
 		switch(event->button) {
 			case 1:
 				PerMouseLeftPressed(padbits);
@@ -185,7 +184,7 @@ static gboolean yui_gl_button_press(GtkWidget * widget, GdkEventButton * event,
 }
 
 static gboolean yui_gl_button_release(GtkWidget * widget, GdkEventButton * event, gpointer user_data) {
-	if (*((u8 *) padbits) == PERMOUSE) {
+	if (PerGetId(padbits) == PERMOUSE) {
 		switch(event->button) {
 			case 1:
 				PerMouseLeftReleased(padbits);
@@ -253,7 +252,36 @@ void yui_gl_dump_screen(YuiGl * glxarea) {
 
         glReadPixels(0, 0, glxarea->pixels_width, glxarea->pixels_height, GL_RGB, GL_UNSIGNED_BYTE, glxarea->pixels);
 #else
-	glxarea->pixels = dispbuffer;
+	int buf_width, buf_height;
+	int i, j;
+	int size;
+	int cur = 0;
+	u8 * pixels;
+	u8 * buffer;
+
+	VIDSoftGetScreenSize( &buf_width, &buf_height );
+	size = buf_width * buf_height * 3;
+
+	glxarea->pixels_width = GTK_WIDGET(glxarea)->allocation.width;
+	glxarea->pixels_height = GTK_WIDGET(glxarea)->allocation.height;
+	glxarea->pixels_rowstride = glxarea->pixels_width * 3;
+	glxarea->pixels_rowstride += (glxarea->pixels_rowstride % 4)? (4 - (glxarea->pixels_rowstride % 4)): 0;
+
+	if (! glxarea->pixels) glxarea->pixels = malloc(sizeof(u8) * size);
+
+	pixels = glxarea->pixels;
+	pixels += size - (buf_width * 3);
+	buffer = dispbuffer;
+
+	for(i = 0;i < buf_height;i++) {
+		for(j = 0;j < buf_width;j++) {
+			*pixels++ = buffer[cur];
+			*pixels++ = buffer[cur + 1];
+			*pixels++ = buffer[cur + 2];
+			cur += 4;
+		}
+		pixels -= buf_width * 6;
+	}
 #endif
 }
 
