@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include "settings.h"
@@ -29,6 +29,16 @@
 YuiRangeItem sh2interpreters[] = {
   { "0", "Fast Interpreter" },
   { "1", "Debug Interpreter" },
+#ifdef TEST_PSP_SH2
+  { "1486", "PSP Interpreter (for debugging)" },
+#endif
+  { 0, 0 }
+};
+
+YuiRangeItem m68kinterpreters[] = {
+  { "1", "Standard Interpreter" },
+  { "2", "Q68 Interpreter" },
+  { "0", "Disabled" },
   { 0, 0 }
 };
 
@@ -81,13 +91,15 @@ YuiRangeItem sndcores[] = {
 	{ "0", "Dummy Sound Interface" },
 #ifdef HAVE_LIBSDL
 	{ "1", "SDL Sound Interface" },
+#endif
+#ifdef HAVE_LIBAL
+	{ "2", "OpenAL Sound Interface" },
 #endif
 	{ 0, 0 }
 };
 
-const gchar * keys1[] = { "Up", "Right", "Down", "Left", "Right trigger", "Left trigger", 0 };
+const gchar * keys1[] = { "Up", "Right", "Down", "Left", "R", "L", 0 };
 const gchar * keys2[] = { "A", "B", "C", "X", "Y", "Z", "Start", 0 };
-const gchar * keys3[] = { "Left", "Middle", "Right", "Start", 0 };
 
 YuiRangeItem vidformats[] = {
 	{ "0", "NTSC" },
@@ -98,7 +110,10 @@ YuiRangeItem vidformats[] = {
 YuiRangeItem percores[] = {
 	{ "2", "Gtk Input Interface" },
 #ifdef HAVE_LIBSDL
-	{ "3", "Joystick Input Interface" },
+	{ "3", "SDL Joystick Interface" },
+#endif
+#ifdef ARCH_IS_LINUX
+	{ "4", "Linux Joystick Interface" },
 #endif
 	{ 0, 0 }
 };
@@ -188,7 +203,7 @@ static void pertype_display_mouse(GtkWidget * box)
    GtkWidget * table5;
    GtkWidget * box_percore = gtk_vbox_new(FALSE, 10);
    GtkWidget * select_percore = yui_range_new(keyfile, "General", "MousePerCore", mousepercores);
-   GList * entrylist;
+   GList * entrylist = NULL;
 
    gtk_container_set_border_width(GTK_CONTAINER(select_percore), 0);
    gtk_container_set_border_width(GTK_CONTAINER(box_percore), 10);
@@ -203,7 +218,7 @@ static void pertype_display_mouse(GtkWidget * box)
 
    gtk_box_pack_start (GTK_BOX (box), gtk_vseparator_new(), TRUE, TRUE, 0);
 
-   table5 = yui_input_entry_new(keyfile, "Mouse", keys3);
+   table5 = yui_input_entry_new(keyfile, "Mouse", PerMouseNames);
    entrylist = g_list_append(entrylist, table5);
    gtk_container_set_border_width(GTK_CONTAINER(table5), 10);
    gtk_box_pack_start (GTK_BOX (box), table5, TRUE, TRUE, 0);
@@ -428,6 +443,9 @@ GtkWidget* create_dialog1(void) {
   box = yui_page_add(YUI_PAGE(advanced), _("SH2 Interpreter"));
   gtk_container_add(GTK_CONTAINER(box), yui_range_new(keyfile, "General", "SH2Int", sh2interpreters));
 
+  box = yui_page_add(YUI_PAGE(advanced), _("M68k Interpreter"));
+  gtk_container_add(GTK_CONTAINER(box), yui_range_new(keyfile, "General", "M68kInt", m68kinterpreters));
+
 #ifdef HAVE_LIBMINI18N
   box = yui_page_add(YUI_PAGE(advanced), _("Translation"));
   gtk_container_add(GTK_CONTAINER(box), yui_file_entry_new(keyfile, "General", "TranslationPath", YUI_FILE_ENTRY_BROWSE, NULL));
