@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <gtk/gtk.h>
@@ -227,7 +227,7 @@ static void yui_transfer_exec(UNUSED GtkWidget * widget, YuiTransfer * yt) {
 		case YUI_TRANSFER_STORE:
 			sscanf(gtk_entry_get_text(GTK_ENTRY(yt->from_entry)), "%x", &from);
 			sscanf(gtk_entry_get_text(GTK_ENTRY(yt->to_entry)), "%x", &to);
-			MappedMemorySave(gtk_entry_get_text(GTK_ENTRY(yt->file_entry)), from, to);
+			MappedMemorySave(gtk_entry_get_text(GTK_ENTRY(yt->file_entry)), from, to - from);
 			break;
 	}
 
