@@ -15,9 +15,12 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+#ifdef PSP  // see FIXME in T1MemoryInit()
+# include <stdint.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -37,6 +40,18 @@
 #include "vdp1.h"
 #include "vdp2.h"
 #include "yabause.h"
+#include "movie.h"
+
+#ifdef HAVE_LIBGL
+#define USE_OPENGL
+#endif
+
+#ifdef USE_OPENGL
+#include "ygl.h"
+#endif
+
+#include "vidsoft.h"
+#include "vidogl.h"
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -57,14 +72,34 @@ u8 *BupRam;
 
 u8 * T1MemoryInit(u32 size)
 {
+#ifdef PSP  // FIXME: could be ported to all arches, but requires stdint.h
+            //        for uintptr_t
+   u8 * base;
+   u8 * mem;
+
+   if ((base = calloc((size * sizeof(u8)) + sizeof(u8 *) + 64, 1)) == NULL)
+      return NULL;
+
+   mem = base + sizeof(u8 *);
+   mem = mem + (64 - ((uintptr_t) mem & 63));
+   *(u8 **)(mem - sizeof(u8 *)) = base; // Save base pointer below memory block
+
+   return mem;
+#else
    return calloc(size, sizeof(u8));
+#endif
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void T1MemoryDeInit(u8 * mem)
 {
+#ifdef PSP
+   if (mem)
+      free(*(u8 **)(mem - sizeof(u8 *)));
+#else
    free(mem);
+#endif
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -875,6 +910,12 @@ void MappedMemoryLoadExec(const char *filename, u32 pc)
          free(p);
          return;
       }
+      else if(strcmp(p, ".ELF") == 0)
+      {
+         MappedMemoryLoadElf(filename);
+         free(p);
+         return;
+      }
 
       free(p);
    }
@@ -936,6 +977,14 @@ int YabSaveState(const char *filename)
    FILE *fp;
    int offset;
    IOCheck_struct check;
+   u8 *buf;
+   int totalsize;
+   int outputwidth;
+   int outputheight;
+   int movieposition;
+
+   //use a second set of savestates for movies
+   MakeMovieStateName(filename);
 
    if ((fp = fopen(filename, "wb")) == NULL)
       return -1;
@@ -951,13 +1000,19 @@ int YabSaveState(const char *filename)
 #endif
 
    // Write version(fix me)
-   i = 1;
+   i = 2;
    ywrite(&check, (void *)&i, sizeof(i), 1, fp);
 
    // Skip the next 4 bytes for now
    i = 0;
    ywrite(&check, (void *)&i, sizeof(i), 1, fp);
 
+   //write frame number
+   ywrite(&check, (void *)&framecounter, 4, 1, fp);
+
+   //this will be updated with the movie position later
+   ywrite(&check, (void *)&framecounter, 4, 1, fp);
+
    // Go through each area and write each state
    i += CartSaveState(fp);
    i += Cs2SaveState(fp);
@@ -986,11 +1041,39 @@ int YabSaveState(const char *filename)
    ywrite(&check, (void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
    ywrite(&check, (void *)&yabsys.IsPal, sizeof(int), 1, fp);
 
+   VIDCore->GetGlSize(&outputwidth, &outputheight);
+
+   totalsize=outputwidth * outputheight * sizeof(u32);
+
+   if ((buf = (u8 *)malloc(totalsize)) == NULL)
+   {
+      return -2;
+   }
+
+   YuiSwapBuffers();
+   #ifdef USE_OPENGL
+   glPixelZoom(1,1);
+   glReadBuffer(GL_BACK);
+   glReadPixels(0, 0, outputwidth, outputheight, GL_RGBA, GL_UNSIGNED_BYTE, buf);
+   #endif
+   YuiSwapBuffers();
+
+   ywrite(&check, (void *)&outputwidth, sizeof(outputwidth), 1, fp);
+   ywrite(&check, (void *)&outputheight, sizeof(outputheight), 1, fp);
+
+   ywrite(&check, (void *)buf, totalsize, 1, fp);
+
+   movieposition=ftell(fp);
+   //write the movie to the end of the savestate
+   SaveMovieInState(fp, check);
+
    i += StateFinishHeader(fp, offset);
 
    // Go back and update size
    fseek(fp, 8, SEEK_SET);
    ywrite(&check, (void *)&i, sizeof(i), 1, fp);
+   fseek(fp, 16, SEEK_SET);
+   ywrite(&check, (void *)&movieposition, sizeof(movieposition), 1, fp);
 
    fclose(fp);
 
@@ -1004,12 +1087,23 @@ int YabLoadState(const char *filename)
    FILE *fp;
    char id[3];
    u8 endian;
-   int version, size, chunksize;
+   int headerversion, version, size, chunksize, headersize;
    IOCheck_struct check;
+   u8* buf;
+   int totalsize;
+   int outputwidth;
+   int outputheight;
+   int curroutputwidth;
+   int curroutputheight;
+   int movieposition;
+
+   MakeMovieStateName(filename);
 
    if ((fp = fopen(filename, "rb")) == NULL)
       return -1;
 
+   headersize = 0xC;
+
    // Read signature
    yread(&check, (void *)id, 1, 3, fp);
 
@@ -1021,8 +1115,27 @@ int YabLoadState(const char *filename)
 
    // Read header
    yread(&check, (void *)&endian, 1, 1, fp);
-   yread(&check, (void *)&version, 4, 1, fp);
+   yread(&check, (void *)&headerversion, 4, 1, fp);
    yread(&check, (void *)&size, 4, 1, fp);
+   switch(headerversion)
+   {
+      case 1:
+         /* This is the "original" version of the format */
+         break;
+      case 2:
+         /* version 2 adds video recording */
+         yread(&check, (void *)&framecounter, 4, 1, fp);
+		 movieposition=ftell(fp);
+		 yread(&check, (void *)&movieposition, 4, 1, fp);
+         headersize = 0x14;
+         break;
+      default:
+         /* we're trying to open a save state using a future version
+          * of the YSS format, that won't work, sorry :) */
+         fclose(fp);
+         return -3;
+         break;
+   }
 
 #ifdef WORDS_BIGENDIAN
    if (endian == 1)
@@ -1038,12 +1151,13 @@ int YabLoadState(const char *filename)
 
    // Make sure size variable matches actual size minus header
    fseek(fp, 0, SEEK_END);
-   if (size != (ftell(fp) - 0xC))
+
+   if (size != (ftell(fp) - headersize))
    {
       fclose(fp);
       return -2;
    }
-   fseek(fp, 0xC, SEEK_SET);
+   fseek(fp, headersize, SEEK_SET);
 
    // Verify version here
 
@@ -1152,6 +1266,40 @@ int YabLoadState(const char *filename)
    yread(&check, (void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
    yread(&check, (void *)&yabsys.IsPal, sizeof(int), 1, fp);
 
+   if (headerversion > 1) {
+
+   yread(&check, (void *)&outputwidth, sizeof(outputwidth), 1, fp);
+   yread(&check, (void *)&outputheight, sizeof(outputheight), 1, fp);
+
+   totalsize=outputwidth * outputheight * sizeof(u32);
+
+   if ((buf = (u8 *)malloc(totalsize)) == NULL)
+   {
+      return -2;
+   }
+
+   yread(&check, (void *)buf, totalsize, 1, fp);
+
+   YuiSwapBuffers();
+
+   #ifdef USE_OPENGL
+   if(VIDCore->id == VIDCORE_SOFT)
+     glRasterPos2i(0, outputheight);
+   if(VIDCore->id == VIDCORE_OGL)
+	 glRasterPos2i(0, outputheight/2);
+   #endif
+
+   VIDCore->GetGlSize(&curroutputwidth, &curroutputheight);
+   #ifdef USE_OPENGL
+   glPixelZoom((float)curroutputwidth / (float)outputwidth, ((float)curroutputheight / (float)outputheight));
+   glDrawPixels(outputwidth, outputheight, GL_RGBA, GL_UNSIGNED_BYTE, buf);
+   #endif
+   YuiSwapBuffers();
+
+   fseek(fp, movieposition, SEEK_SET);
+   MovieReadState(fp, filename);
+   }
+   
    fclose(fp);
 
    ScspUnMuteAudio();
@@ -1250,7 +1398,7 @@ static int SearchString(u32 startaddr, u32 endaddr, int searchtype,
    switch (searchtype & 0x70)
    {
       case SEARCHSTRING:
-         strcpy(buf, searchstr);
+         strcpy((char *)buf, searchstr);
          break;
       case SEARCHREL8BIT:
       case SEARCHREL16BIT:
@@ -1371,7 +1519,7 @@ result_struct *MappedMemorySearch(u32 startaddr, u32 endaddr, int searchtype,
    u32 i=0;
    result_struct *results;
    u32 numresults=0;
-   u32 searchval;
+   unsigned long searchval;
    int issigned=0;
    u32 addr;
 
@@ -1399,11 +1547,11 @@ result_struct *MappedMemorySearch(u32 startaddr, u32 endaddr, int searchtype,
          sscanf(searchstr, "%08lx", &searchval);
          break;
       case SEARCHUNSIGNED:
-         searchval = (u32)atoi(searchstr);
+         searchval = (unsigned long)atoi(searchstr);
          issigned = 0;
          break;
       case SEARCHSIGNED:
-         searchval = (u32)atoi(searchstr);
+         searchval = (unsigned long)atoi(searchstr);
          issigned = 1;
          break;
    }   
