@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef MEMORY_H
@@ -224,7 +224,7 @@ static INLINE int T123Load(void * mem, u32 size, int type, const char *filename)
       return -1;
    }
 
-   filesizecheck = fread((void *)buffer, 1, filesize, fp);
+   filesizecheck = (u32)fread((void *)buffer, 1, filesize, fp);
    fclose(fp);
 
    if (filesizecheck != filesize) return -1;
@@ -310,7 +310,7 @@ static INLINE int T123Save(void * mem, u32 size, int type, const char *filename)
       return -1;
    }
 
-   sizecheck = fwrite((void *)buffer, 1, size, fp);
+   sizecheck = (u32)fwrite((void *)buffer, 1, size, fp);
    fclose(fp);
    free(buffer);
 
