@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef PERIPHERAL_H
@@ -51,7 +51,7 @@ typedef struct
    void (*DeInit)(void);
    int (*HandleEvents)(void);
    void (*PerSetButtonMapping)();
-   u32 (*Scan)(const char *);
+   u32 (*Scan)(void);
    int canScan;
    void (*Flush)(void);
 #ifdef PERKEYNAME
@@ -91,6 +91,7 @@ void PerDeInit(void);
  * PerPadAdd() or PerMouseAdd() instead.
  */
 void * PerAddPeripheral(PortData_struct *port, int perid);
+int PerGetId(void * peripheral);
 void PerPortReset(void);
 /**
  * Iterate the list of peripherals connected to a port
@@ -120,6 +121,8 @@ void PerSetKey(u32 key, u8 name, void * controller);
 #define PERPAD_Y	11
 #define PERPAD_Z	12
 
+extern const char * PerPadNames[14];
+
 typedef struct
 {
    u8 perid;
@@ -182,6 +185,8 @@ void PerPadLTriggerReleased(PerPad_struct * pad);
 #define PERMOUSE_RIGHT	15
 #define PERMOUSE_START	16
 
+extern const char * PerMouseNames[5];
+
 typedef struct
 {
    u8 perid;
