@@ -16,7 +16,7 @@
 
 	You should have received a copy of the GNU General Public License
 	along with Yabause; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 #ifndef QTYABAUSE_H
 #define QTYABAUSE_H
@@ -32,8 +32,10 @@ extern "C"
 	#include "../cs0.h"
 	#include "../cdbase.h"
 	#include "../scsp.h"
+	#include "../sndal.h"
 	#include "../sndsdl.h"
 	#include "../persdljoy.h"
+	#include "../permacjoy.h"
 	#include "../debug.h"
 	#include "../m68kcore.h"
 	#include "../m68kc68k.h"
@@ -53,6 +55,7 @@ extern "C"
 }
 
 #include <QString>
+#include <QMap>
 
 class UIYabause;
 class Settings;
@@ -86,6 +89,10 @@ namespace QtYabause
 	VideoInterface_struct defaultVIDCore();
 	PerInterface_struct defaultPERCore();
 	SH2Interface_struct defaultSH2Core();
+	
+	// padsbits
+	QMap<uint, PerPad_struct*>* portPadsBits( uint portNumber );
+	void clearPadsBits();
 };
 
 #endif // QTYABAUSE_H
