@@ -16,12 +16,13 @@
 
 	You should have received a copy of the GNU General Public License
 	along with Yabause; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 #include "UISettings.h"
 #include "../Settings.h"
 #include "../CommonDialogs.h"
 #include "UIWaitInput.h"
+#include "UIPortManager.h"
 
 #include <QDir>
 #include <QList>
@@ -76,8 +77,15 @@ UISettings::UISettings( QWidget* p )
 {
 	// setup dialog
 	setupUi( this );
+	pmPort1->setPort( 1 );
+	pmPort1->loadSettings();
+	pmPort2->setPort( 2 );
+	pmPort2->loadSettings();
+	
 	if ( p && !p->isFullScreen() )
+	{
 		setWindowFlags( Qt::Sheet );
+	}
 
 	// load cores informations
 	loadCores();
@@ -87,9 +95,9 @@ UISettings::UISettings( QWidget* p )
 	
 	// connections
 	foreach ( QToolButton* tb, findChildren<QToolButton*>() )
+	{
 		connect( tb, SIGNAL( clicked() ), this, SLOT( tbBrowse_clicked() ) );
-	foreach ( QPushButton* pb, wInput->findChildren<QPushButton*>() )
-		connect( pb, SIGNAL( clicked() ), this, SLOT( pbInputs_clicked() ) );
+	}
 	
 	// retranslate widgets
 	QtYabause::retranslateWidget( this );
@@ -147,58 +155,49 @@ void UISettings::tbBrowse_clicked()
 		requestFile( QtYabause::translate( "Choose a mpeg rom" ), leMpegROM );
 }
 
-void UISettings::pbInputs_clicked()
+void UISettings::on_cbInput_currentIndexChanged( int id )
 {
-	// get per core id
-	int i = cbInput->itemData( cbInput->currentIndex() ).toInt();
+	PerInterface_struct* core = QtYabause::getPERCore( cbInput->itemData( id ).toInt() );
 	
-	// get percore pointer
-	PerInterface_struct* c = QtYabause::getPERCore( i );
-
-	// request user input
-	if ( c )
-	{
-		QPushButton* pb = qobject_cast<QPushButton*>( sender() );
-		const QString key = pb->objectName().mid( 2 );
-		UIWaitInput wi( c, key, window() );
-		if ( wi.exec() )
-			wInput->findChild<QLabel*>( QString( "l%1" ).arg( key ) )->setText( wi.keyString() );
-	}
+	Q_ASSERT( core );
+	
+	pmPort1->setCore( core );
+	pmPort2->setCore( core );
 }
 
 void UISettings::loadCores()
 {
 	// CD Drivers
 	for ( int i = 0; CDCoreList[i] != NULL; i++ )
-		cbCdRom->addItem( CDCoreList[i]->Name, CDCoreList[i]->id );
+		cbCdRom->addItem( QtYabause::translate( CDCoreList[i]->Name ), CDCoreList[i]->id );
 	
 	// VDI Drivers
 	for ( int i = 0; VIDCoreList[i] != NULL; i++ )
-		cbVideoCore->addItem( VIDCoreList[i]->Name, VIDCoreList[i]->id );
+		cbVideoCore->addItem( QtYabause::translate( VIDCoreList[i]->Name ), VIDCoreList[i]->id );
 	
 	// Video Formats
 	foreach ( const Item& it, mVideoFromats )
-		cbVideoFormat->addItem( it.Name, it.id );
+		cbVideoFormat->addItem( QtYabause::translate( it.Name ), it.id );
 	
 	// SND Drivers
 	for ( int i = 0; SNDCoreList[i] != NULL; i++ )
-		cbSoundCore->addItem( SNDCoreList[i]->Name, SNDCoreList[i]->id );
+		cbSoundCore->addItem( QtYabause::translate( SNDCoreList[i]->Name ), SNDCoreList[i]->id );
 	
 	// Cartridge Types
 	foreach ( const Item& it, mCartridgeTypes )
-		cbCartridge->addItem( it.Name, it.id );
+		cbCartridge->addItem( QtYabause::translate( it.Name ), it.id );
 	
 	// Input Drivers
 	for ( int i = 0; PERCoreList[i] != NULL; i++ )
-		cbInput->addItem( PERCoreList[i]->Name, PERCoreList[i]->id );
+		cbInput->addItem( QtYabause::translate( PERCoreList[i]->Name ), PERCoreList[i]->id );
 	
 	// Regions
 	foreach ( const Item& it, mRegions )
-		cbRegion->addItem( it.Name, it.id );
+		cbRegion->addItem( QtYabause::translate( it.Name ), it.id );
 	
 	// SH2 Interpreters
 	for ( int i = 0; SH2CoreList[i] != NULL; i++ )
-		cbSH2Interpreter->addItem( SH2CoreList[i]->Name, SH2CoreList[i]->id );
+		cbSH2Interpreter->addItem( QtYabause::translate( SH2CoreList[i]->Name ), SH2CoreList[i]->id );
 }
 
 void UISettings::loadSettings()
@@ -231,9 +230,6 @@ void UISettings::loadSettings()
 	
 	// input
 	cbInput->setCurrentIndex( cbInput->findData( s->value( "Input/PerCore", QtYabause::defaultPERCore().id ).toInt() ) );
-	foreach ( QLabel* l, wInput->findChildren<QLabel*>() )
-		if ( l != lInput )
-			l->setText( s->value( QString( "Input/Keys/%1" ).arg( l->objectName().mid( 1 ) ) ).toString() );
 	
 	// advanced
 	cbRegion->setCurrentIndex( cbRegion->findData( s->value( "Advanced/Region", mRegions.at( 0 ).id ).toString() ) );
@@ -270,9 +266,6 @@ void UISettings::saveSettings()
 	
 	// input
 	s->setValue( "Input/PerCore", cbInput->itemData( cbInput->currentIndex() ).toInt() );
-	foreach ( QLabel* l, wInput->findChildren<QLabel*>() )
-		if ( l != lInput )
-			s->setValue( QString( "Input/Keys/%1" ).arg( l->objectName().mid( 1 ) ), l->text() );
 	
 	// advanced
 	s->setValue( "Advanced/Region", cbRegion->itemData( cbRegion->currentIndex() ).toString() );
