@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <stdlib.h>
@@ -171,15 +171,17 @@ void FASTCALL ScuDMA(scudmainfo_struct *dmainfo) {
          TempReadAddress &= 0x7FFFFFFF;
 
          if ((test >= 0x5A00000) && (test < 0x5FF0000)) {
+            u32 start = TempWriteAddress;
             while(counter < TempTransferNumber) {
                u32 tmp = MappedMemoryReadLong(TempReadAddress);
-               MappedMemoryWriteWord(TempWriteAddress, tmp >> 16);
+               MappedMemoryWriteWord(TempWriteAddress, (u16)(tmp >> 16));
                TempWriteAddress += WriteAdd;
-               MappedMemoryWriteWord(TempWriteAddress, tmp & 0xFFFF);
+               MappedMemoryWriteWord(TempWriteAddress, (u16)tmp);
                TempWriteAddress += WriteAdd;
                TempReadAddress += ReadAdd;
                counter += 4;
             }
+            SH2WriteNotify(start, TempWriteAddress - start);
          }
          else {
             LOG("indirect DMA, A Bus, not implemented\n");
@@ -221,24 +223,28 @@ void FASTCALL ScuDMA(scudmainfo_struct *dmainfo) {
       }
 
       if ((test >= 0x5A00000) && (test < 0x5FF0000)) {
+         u32 start = dmainfo->WriteAddress;
          while(counter < dmainfo->TransferNumber) {
             u32 tmp = MappedMemoryReadLong(dmainfo->ReadAddress);
-            MappedMemoryWriteWord(dmainfo->WriteAddress, tmp >> 16);
+            MappedMemoryWriteWord(dmainfo->WriteAddress, (u16)(tmp >> 16));
             dmainfo->WriteAddress += WriteAdd;
-            MappedMemoryWriteWord(dmainfo->WriteAddress, tmp & 0xFFFF);
+            MappedMemoryWriteWord(dmainfo->WriteAddress, (u16)tmp);
             dmainfo->WriteAddress += WriteAdd;
             dmainfo->ReadAddress += ReadAdd;
             counter += 4;
          }
+         SH2WriteNotify(start, dmainfo->WriteAddress - start);
       }
-      else {
-         LOG("direct DMA, A Bus, not tested yet\n");
+      else {     
+         u32 start = dmainfo->WriteAddress;
+		 LOG("direct DMA, A Bus, not tested yet\n");
          while(counter < dmainfo->TransferNumber) {
             MappedMemoryWriteLong(dmainfo->WriteAddress, MappedMemoryReadLong(dmainfo->ReadAddress));
             dmainfo->ReadAddress += ReadAdd;
             dmainfo->WriteAddress += WriteAdd;
             counter += 4;
          }
+         SH2WriteNotify(start, dmainfo->WriteAddress - start);
       }
       switch(dmainfo->mode) {
          case 0:
@@ -285,9 +291,9 @@ u32 readgensrc(u8 num)
          ScuDsp->CT[3]++;
          return val;
       case 0x9: // ALL
-         return ScuDsp->ALU.part.L;
+         return (u32)ScuDsp->ALU.part.L;
       case 0xA: // ALH
-         return ScuDsp->ALU.part.H;
+         return (u32)ScuDsp->ALU.part.H;
       default: break;
    }
 
@@ -328,22 +334,22 @@ void writed1busdest(u8 num, u32 val)
           ScuDsp->WA0 = val;
           return;
       case 0xA:
-          ScuDsp->LOP = val;
+          ScuDsp->LOP = (u16)val;
           return;
       case 0xB:
-          ScuDsp->TOP = val;
+          ScuDsp->TOP = (u8)val;
           return;
       case 0xC:
-          ScuDsp->CT[0] = val;
+          ScuDsp->CT[0] = (u8)val;
           return;
       case 0xD:
-          ScuDsp->CT[1] = val;
+          ScuDsp->CT[1] = (u8)val;
           return;
       case 0xE:
-          ScuDsp->CT[2] = val;
+          ScuDsp->CT[2] = (u8)val;
           return;
       case 0xF:
-          ScuDsp->CT[3] = val;
+          ScuDsp->CT[3] = (u8)val;
           return;
       default: break;
    }
@@ -383,7 +389,7 @@ void writeloadimdest(u8 num, u32 val)
           ScuDsp->WA0 = val;
           return;
       case 0xA: // LOP
-          ScuDsp->LOP = val;
+          ScuDsp->LOP = (u16)val;
           return;
       case 0xC: // PC->TOP, PC
           ScuDsp->TOP = ScuDsp->PC;
@@ -838,16 +844,19 @@ void ScuExec(u32 timing) {
                      if (direction)
                      {
                         u32 WA0temp=ScuDsp->WA0;
+						u32 start;
 
                         // Looks like some bits are ignored on a real saturn(Grandia takes advantage of this)
                         ScuDsp->WA0 &= 0x01FFFFFF;
 
                         // DMA(H) [RAM], D0, ??
+                        start = ScuDsp->WA0 << 2;
                         for (i = 0; i < transferNumber; i++)
                         {                        
                            MappedMemoryWriteLong(ScuDsp->WA0 << 2, readdmasrc((instruction >> 8) & 0x3, 1));
                            ScuDsp->WA0 += (addressAdd >> 2); 
                         }
+                        SH2WriteNotify(start, (ScuDsp->WA0 << 2) - start);
 
                         if (hold) ScuDsp->WA0 = WA0temp;
                      }
@@ -1517,6 +1526,74 @@ void ScuDspStep(void) {
 
 //////////////////////////////////////////////////////////////////////////////
 
+int ScuDspSaveProgram(const char *filename) {
+   FILE *fp;
+   u32 i;
+   u8 *buffer;
+
+   if (!filename)
+      return -1;
+
+   if ((fp = fopen(filename, "wb")) == NULL)
+      return -1;
+
+   if ((buffer = (u8 *)malloc(sizeof(ScuDsp->ProgramRam))) == NULL)
+   {
+      fclose(fp);
+      return -2;
+   }
+
+   for (i = 0; i < 256; i++)
+   {
+      buffer[i * 4] = (u8)(ScuDsp->ProgramRam[i] >> 24);
+      buffer[(i * 4)+1] = (u8)(ScuDsp->ProgramRam[i] >> 16);
+      buffer[(i * 4)+2] = (u8)(ScuDsp->ProgramRam[i] >> 8);
+      buffer[(i * 4)+3] = (u8)ScuDsp->ProgramRam[i];
+   }
+
+   fwrite((void *)buffer, 1, sizeof(ScuDsp->ProgramRam), fp);
+   fclose(fp);
+   free(buffer);
+
+   return 0;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+int ScuDspSaveMD(const char *filename, int num) {
+   FILE *fp;
+   u32 i;
+   u8 *buffer;
+
+   if (!filename)
+      return -1;
+
+   if ((fp = fopen(filename, "wb")) == NULL)
+      return -1;
+
+   if ((buffer = (u8 *)malloc(sizeof(ScuDsp->MD[num]))) == NULL)
+   {
+      fclose(fp);
+      return -2;
+   }
+
+   for (i = 0; i < 64; i++)
+   {
+      buffer[i * 4] = (u8)(ScuDsp->MD[num][i] >> 24);
+      buffer[(i * 4)+1] = (u8)(ScuDsp->MD[num][i] >> 16);
+      buffer[(i * 4)+2] = (u8)(ScuDsp->MD[num][i] >> 8);
+      buffer[(i * 4)+3] = (u8)ScuDsp->MD[num][i];
+   }
+
+   fwrite((void *)buffer, 1, sizeof(ScuDsp->MD[num]), fp);
+   fclose(fp);
+   free(buffer);
+
+   return 0;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 void ScuDspGetRegisters(scudspregs_struct *regs) {
    if (regs != NULL) {
       memcpy(regs->ProgramRam, ScuDsp->ProgramRam, sizeof(u32) * 256);
