@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 // SH2 Shared Code
@@ -145,7 +145,7 @@ void SH2PowerOn(SH2_struct *context) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL SH2Exec(SH2_struct *context, u32 cycles)
+void FASTCALL SH2Exec(SH2_struct *context, u32 cycles)
 {
    CurrentSH2 = context;
 
@@ -161,16 +161,20 @@ u32 FASTCALL SH2Exec(SH2_struct *context, u32 cycles)
          context->regs.SR.part.I = context->interrupts[context->NumberOfInterrupts-1].level;
          context->regs.PC = MappedMemoryReadLong(context->regs.VBR + (context->interrupts[context->NumberOfInterrupts-1].vector << 2));
          context->NumberOfInterrupts--;
-	 context->isIdle = 0;
+         context->isIdle = 0;
+         context->isSleeping = 0;
       }
    }
 
    SH2Core->Exec(context, cycles);
-  
+
    FRTExec(cycles);
    WDTExec(cycles);
 
-   return 0; // fix me
+   if (UNLIKELY(context->cycles < cycles))
+      context->cycles = 0;
+   else
+      context->cycles -= cycles;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -252,6 +256,13 @@ void SH2SetRegisters(SH2_struct *context, sh2regs_struct * r)
 
 //////////////////////////////////////////////////////////////////////////////
 
+void SH2WriteNotify(u32 start, u32 length) {
+   if (SH2Core->WriteNotify)
+      SH2Core->WriteNotify(start, length);
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 void SH2SetBreakpointCallBack(SH2_struct *context, void (*func)(void *, u32)) {
    context->bp.BreakpointCallBack = func;
 }
@@ -1476,15 +1487,25 @@ void FASTCALL DataArrayWriteLong(u32 addr, u32 val)  {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FRTExec(UNUSED u32 cycles) {
+#ifdef PSP_TIMING_TWEAKS
+void FRTExec(u32 cycles)
+#else
+void FRTExec(UNUSED u32 cycles)
+#endif
+{
    u32 frcold;
    u32 frctemp;
 
    frcold = frctemp = (u32)CurrentSH2->onchip.FRC.all;
    
    // Increment FRC
+#ifdef PSP_TIMING_TWEAKS
+   frctemp += ((cycles + CurrentSH2->frc.leftover) / CurrentSH2->frc.div);
+   CurrentSH2->frc.leftover = (cycles + CurrentSH2->frc.leftover) % CurrentSH2->frc.div;
+#else
    frctemp += ((CurrentSH2->cycles + CurrentSH2->frc.leftover) / CurrentSH2->frc.div);
    CurrentSH2->frc.leftover = (CurrentSH2->cycles + CurrentSH2->frc.leftover) % CurrentSH2->frc.div;
+#endif
 
    // Check to see if there is or was a Output Compare A match
    if (frctemp >= CurrentSH2->onchip.OCRA && frcold < CurrentSH2->onchip.OCRA)
