@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifdef HAVE_LIBSDL
@@ -35,7 +35,7 @@ int SNDSDLInit();
 void SNDSDLDeInit();
 int SNDSDLReset();
 int SNDSDLChangeVideoFormat(int vertfreq);
-void sdlConvert32uto16s(s32 *srcL, s32 *srcR, s16 *dst, u32 len);
+static void sdlConvert32uto16s(s32 *srcL, s32 *srcR, s16 *dst, u32 len);
 void SNDSDLUpdateAudio(u32 *leftchanbuffer, u32 *rightchanbuffer, u32 num_samples);
 u32 SNDSDLGetAudioSpace();
 void SNDSDLMuteAudio();
@@ -165,7 +165,7 @@ int SNDSDLChangeVideoFormat(int vertfreq)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void sdlConvert32uto16s(s32 *srcL, s32 *srcR, s16 *dst, u32 len) {
+static void sdlConvert32uto16s(s32 *srcL, s32 *srcR, s16 *dst, u32 len) {
    u32 i;
 
    for (i = 0; i < len; i++)
