@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef VDP1_H
@@ -59,6 +59,7 @@ typedef struct
    void FASTCALL (*Vdp2SetPriorityNBG3)(int);
    void FASTCALL (*Vdp2SetPriorityRBG0)(int);
    void (*OnScreenDebugMessage)(char *string, ...);
+   void (*GetGlSize)(int *width, int *height);
 } VideoInterface_struct;
 
 extern VideoInterface_struct *VIDCore;
