@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <stdlib.h>
@@ -25,6 +25,10 @@
 #include "sh2core.h"
 #include "vdp1.h"
 #include "yabause.h"
+#include "movie.h"
+
+char OSDMessage[32] = "";	//adelikat: For showing on screen messages such as savestate loaded/saved
+int OSDMessageTimer = 120;
 
 u8 * Vdp2Ram;
 u8 * Vdp2ColorRam;
@@ -47,6 +51,26 @@ static int fpsframecount=0;
 static u64 fpsticks;
 static int fpstoggle=0;
 
+//////////////////////////////////////////////////////////////////////////////
+int GetOSDToggle()
+{
+	return fpstoggle;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+void SetOSDToggle(int toggle)
+{
+	fpstoggle = toggle;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+//adelikat: This function will handle the OSDMessage variable properly, it should be used by other functions for displaying information to the user
+void DisplayMessage(const char* str)
+{
+	strcpy(OSDMessage, str);
+	OSDMessageTimer = 120;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 
 u8 FASTCALL Vdp2RamReadByte(u32 addr) {
@@ -283,8 +307,11 @@ void FPSDisplay(void)
 {
    if (fpstoggle)
    {
-      VIDCore->OnScreenDebugMessage("%02d/%02d FPS", fps, yabsys.IsPal ? 50 : 60);
-
+      if (!OSDMessageTimer)
+		OSDMessage[0] = 0;
+	  VIDCore->OnScreenDebugMessage("%02d/%02d FPS %d %d %s %s %s", fps, yabsys.IsPal ? 50 : 60, framecounter, lagframecounter, MovieStatus, InputDisplayString, OSDMessage);
+	  if (OSDMessageTimer > 0)
+		  OSDMessageTimer--;
       fpsframecount++;
       if(YabauseGetTicks() >= fpsticks + yabsys.tickfreq)
       {
@@ -358,7 +385,8 @@ void Vdp2VBlankOUT(void) {
       if (framestoskip < 1)
          framestoskip = 6;
    }
-   else if (autoframeskipenab)
+   //when in frame advance, disable frame skipping
+   else if (autoframeskipenab && FrameAdvanceVariable == 0)
    {
       framecount++;
 
@@ -1344,5 +1372,4 @@ void DisableAutoFrameSkip(void)
    autoframeskipenab = 0;
 }
 
-//////////////////////////////////////////////////////////////////////////////
-
+//////////////////////////////////////////////////////////////////////////////
\ No newline at end of file
