@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifdef HAVE_LIBGL
@@ -90,6 +90,7 @@ void FASTCALL VIDOGLVdp2SetPriorityNBG1(int priority);
 void FASTCALL VIDOGLVdp2SetPriorityNBG2(int priority);
 void FASTCALL VIDOGLVdp2SetPriorityNBG3(int priority);
 void FASTCALL VIDOGLVdp2SetPriorityRBG0(int priority);
+void YglGetGlSize(int *width, int *height);
 
 VideoInterface_struct VIDOGL = {
 VIDCORE_OGL,
@@ -120,7 +121,8 @@ VIDOGLVdp2SetPriorityNBG1,
 VIDOGLVdp2SetPriorityNBG2,
 VIDOGLVdp2SetPriorityNBG3,
 VIDOGLVdp2SetPriorityRBG0,
-YglOnScreenDebugMessage
+YglOnScreenDebugMessage,
+YglGetGlSize
 };
 
 static float vdp1wratio=1;
@@ -139,6 +141,9 @@ static int rbg0priority=0;
 
 static u32 Vdp2ColorRamGetColor(u32 colorindex, int alpha);
 
+static int GlHeight=320;
+static int GlWidth=224;
+
 //////////////////////////////////////////////////////////////////////////////
 
 static void FASTCALL Vdp1ReadTexture(vdp1cmd_struct *cmd, YglSprite *sprite, YglTexture *texture)
@@ -1407,6 +1412,9 @@ void VIDOGLResize(unsigned int w, unsigned int h, int on)
    glViewport(0, 0, w, h);
 
    SetSaturnResolution(vdp2width, vdp2height);
+
+   GlHeight=h;
+   GlWidth=w;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1905,11 +1913,12 @@ void VIDOGLVdp1PolygonDraw(void)
    {
       int shadow, priority, colorcalc;
 
+      priority = 0;  // Avoid compiler warning
       Vdp1ProcessSpritePixel(Vdp2Regs->SPCTL & 0xF, &color, &shadow, &priority, &colorcalc);
 #ifdef WORDS_BIGENDIAN
-      polygon.priority = ((u8 *)&Vdp2Regs->PRISA)[priority^1];
+      polygon.priority = ((u8 *)&Vdp2Regs->PRISA)[priority^1] & 0x7;
 #else
-      polygon.priority = ((u8 *)&Vdp2Regs->PRISA)[priority];
+      polygon.priority = ((u8 *)&Vdp2Regs->PRISA)[priority] & 0x7;
 #endif
    }
 
@@ -2746,4 +2755,10 @@ void FASTCALL VIDOGLVdp2SetPriorityRBG0(int priority)
 
 //////////////////////////////////////////////////////////////////////////////
 
+void YglGetGlSize(int *width, int *height)
+{
+   *width = GlWidth;
+   *height = GlHeight;
+}
+
 #endif
