@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef VIDSHARED_H
@@ -68,6 +68,9 @@ typedef struct
    u32 linescrolltbl;
    int wctl;
    int islinewindow;
+   int isverticalscroll;
+   u32 verticalscrolltbl;
+   int verticalscrollinc;
 } vdp2draw_struct;
 
 typedef struct
