@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include "vidsoft.h"
@@ -30,9 +30,10 @@
 
 #ifdef USE_OPENGL
 #include "ygl.h"
-#include "yui.h"
 #endif
 
+#include "yui.h"
+
 #include <stdlib.h>
 #include <stdarg.h>
 
@@ -62,6 +63,9 @@
 				(l & 0xFF000000)
 #endif
 
+static void PushUserClipping(int mode);
+static void PopUserClipping(void);
+
 int VIDSoftInit(void);
 void VIDSoftDeInit(void);
 void VIDSoftResize(unsigned int, unsigned int, int);
@@ -89,6 +93,7 @@ void FASTCALL VIDSoftVdp2SetPriorityNBG2(int priority);
 void FASTCALL VIDSoftVdp2SetPriorityNBG3(int priority);
 void FASTCALL VIDSoftVdp2SetPriorityRBG0(int priority);
 void VIDSoftOnScreenDebugMessage(char *string, ...);
+void VIDSoftGetGlSize(int *width, int *height);
 void VIDSoftVdp1SwapFrameBuffer(void);
 void VIDSoftVdp1EraseFrameBuffer(void);
 
@@ -122,6 +127,7 @@ VIDSoftVdp2SetPriorityNBG2,
 VIDSoftVdp2SetPriorityNBG3,
 VIDSoftVdp2SetPriorityRBG0,
 VIDSoftOnScreenDebugMessage,
+VIDSoftGetGlSize,
 };
 
 u32 *dispbuffer=NULL;
@@ -146,8 +152,10 @@ static int nbg1priority=0;
 static int nbg2priority=0;
 static int nbg3priority=0;
 static int rbg0priority=0;
+#ifdef USE_OPENGL
 static int outputwidth;
 static int outputheight;
+#endif
 static int resxratio;
 static int resyratio;
 
@@ -665,19 +673,23 @@ void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, in
    scrollx = info->x;
    scrolly = info->y;
 
+   clip[0].xstart = clip[0].ystart = clip[0].xend = clip[0].yend = 0;
+   clip[1].xstart = clip[1].ystart = clip[1].xend = clip[1].yend = 0;
    ReadWindowData(info->wctl, clip);
+   linewnd0addr = linewnd1addr = 0;
    ReadLineWindowData(&info->islinewindow, info->wctl, &linewnd0addr, &linewnd1addr);
 
    for (j = 0; j < height; j++)
    {
       int Y;
+      int linescrollx = 0;
       // precalculate the coordinate for the line(it's faster) and do line
       // scroll
       if (info->islinescroll)
       {
          if (info->islinescroll & 0x1)
          {
-            info->x = ((T1ReadLong(Vdp2Ram, info->linescrolltbl) >> 16) & 0x7FF) + scrollx;
+            linescrollx = (T1ReadLong(Vdp2Ram, info->linescrolltbl) >> 16) & 0x7FF;
             info->linescrolltbl += 4;
          }
          if (info->islinescroll & 0x2)
@@ -700,6 +712,17 @@ void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, in
       // if line window is enabled, adjust clipping values
       ReadLineWindowClip(info->islinewindow, clip, &linewnd0addr, &linewnd1addr);
       y &= sinfo.ymask;
+
+      if (info->isverticalscroll)
+      {
+         // this is *wrong*, vertical scroll use a different value per cell
+         // info->verticalscrolltbl should be incremented by info->verticalscrollinc
+         // each time there's a cell change and reseted at the end of the line...
+         // or something like that :)
+         y += T1ReadLong(Vdp2Ram, info->verticalscrolltbl) >> 16;
+         y &= 0x1FF;
+      }
+
       Y=y;
 
       for (i = 0; i < width; i++)
@@ -723,6 +746,11 @@ void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, in
 
          x = info->x+((int)(info->coordincx*(float)((info->mosaicxmask > 1) ? (i / info->mosaicxmask * info->mosaicxmask) : i)));
          x &= sinfo.xmask;
+         if (linescrollx)
+         {
+            x += linescrollx;
+            x &= 0x3FF;
+         }
 
          // Fetch Pixel, if it isn't transparent, continue
          if (!info->isbitmap)
@@ -1072,6 +1100,17 @@ static void Vdp2DrawNBG0(void)
 
    ReadMosaicData(&info, 0x1);
    ReadLineScrollData(&info, Vdp2Regs->SCRCTL & 0xFF, Vdp2Regs->LSTA0.all);
+   if (Vdp2Regs->SCRCTL & 1)
+   {
+      info.isverticalscroll = 1;
+      info.verticalscrolltbl = (Vdp2Regs->VCSTA.all & 0x7FFFE) << 1;
+      if (Vdp2Regs->SCRCTL & 0x100)
+         info.verticalscrollinc = 8;
+      else
+         info.verticalscrollinc = 4;
+   }
+   else
+      info.isverticalscroll = 0;
    info.wctl = Vdp2Regs->WCTLA;
 
    if (info.enable == 1)
@@ -1138,6 +1177,22 @@ static void Vdp2DrawNBG1(void)
 
    ReadMosaicData(&info, 0x2);
    ReadLineScrollData(&info, Vdp2Regs->SCRCTL >> 8, Vdp2Regs->LSTA1.all);
+   if (Vdp2Regs->SCRCTL & 0x100)
+   {
+      info.isverticalscroll = 1;
+      if (Vdp2Regs->SCRCTL & 0x1)
+      {
+         info.verticalscrolltbl = 4 + ((Vdp2Regs->VCSTA.all & 0x7FFFE) << 1);
+         info.verticalscrollinc = 8;
+      }
+      else
+      {
+         info.verticalscrolltbl = (Vdp2Regs->VCSTA.all & 0x7FFFE) << 1;
+         info.verticalscrollinc = 4;
+      }
+   }
+   else
+      info.isverticalscroll = 0;
    info.wctl = Vdp2Regs->WCTLA >> 8;
 
    Vdp2DrawScroll(&info, vdp2framebuffer, vdp2width, vdp2height);
@@ -1176,6 +1231,7 @@ static void Vdp2DrawNBG2(void)
 
    ReadMosaicData(&info, 0x4);
    info.islinescroll = 0;
+   info.isverticalscroll = 0;
    info.wctl = Vdp2Regs->WCTLB;
    info.isbitmap = 0;
 
@@ -1216,6 +1272,7 @@ static void Vdp2DrawNBG3(void)
 
    ReadMosaicData(&info, 0x8);
    info.islinescroll = 0;
+   info.isverticalscroll = 0;
    info.wctl = Vdp2Regs->WCTLB >> 8;
    info.isbitmap = 0;
 
@@ -1307,6 +1364,7 @@ static void Vdp2DrawRBG0(void)
 
    ReadMosaicData(&info, 0x10);
    info.islinescroll = 0;
+   info.isverticalscroll = 0;
    info.wctl = Vdp2Regs->WCTLC;
 
    Vdp2DrawRotationFP(&info, parameter);
@@ -1548,6 +1606,8 @@ void VIDSoftVdp1DistortedSpriteDraw() {
 
   Vdp1ReadCommand(&cmd, Vdp1Regs->addr);
 
+  if (cmd.CMDPMOD & 0x0400) PushUserClipping((cmd.CMDPMOD >> 9) & 0x1);
+
   flipfunction = (cmd.CMDCTRL & 0x30) >> 4;
   {
     s32 vertices[8];
@@ -1731,6 +1791,8 @@ void VIDSoftVdp1DistortedSpriteDraw() {
     yN += yStepC;
     H += stepH;
   }
+
+  if (cmd.CMDPMOD & 0x0400) PopUserClipping();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1738,7 +1800,7 @@ void VIDSoftVdp1DistortedSpriteDraw() {
 void VIDSoftVdp1NormalSpriteDraw(void)
 {
    vdp1cmd_struct cmd;
-   s32 x0, y0, x1, y1, W, H;
+   s16 x0, y0, x1, y1, W, H;
    u8 flip, SPD, endCode;
    u16 colorbank;
    int type;
@@ -1750,6 +1812,7 @@ void VIDSoftVdp1NormalSpriteDraw(void)
    u32 colorlut;
    
    Vdp1ReadCommand(&cmd, Vdp1Regs->addr);
+   if (cmd.CMDPMOD & 0x0400) PushUserClipping((cmd.CMDPMOD >> 9) & 0x1);
 
    x0 = cmd.CMDXA + Vdp1Regs->localX;
    y0 = cmd.CMDYA + Vdp1Regs->localY;
@@ -1938,6 +2001,7 @@ void VIDSoftVdp1NormalSpriteDraw(void)
      iPix += stepPix;
      h0 += stepH;
    }
+   if (cmd.CMDPMOD & 0x0400) PopUserClipping();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1958,6 +2022,7 @@ void VIDSoftVdp1ScaledSpriteDraw(void)
    u32 colorlut;
 
    Vdp1ReadCommand(&cmd, Vdp1Regs->addr);
+   if (cmd.CMDPMOD & 0x0400) PushUserClipping((cmd.CMDPMOD >> 9) & 0x1);
 
    flip = (cmd.CMDCTRL & 0x30) >> 4;
    endCode = (( cmd.CMDPMOD & 0x80) == 0 )?1:0;
@@ -2223,6 +2288,7 @@ void VIDSoftVdp1ScaledSpriteDraw(void)
      iPix += stepPix;
      h0 += stepH;
    }
+   if (cmd.CMDPMOD & 0x0400) PopUserClipping();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -2243,6 +2309,9 @@ void VIDSoftVdp1PolygonDraw(void) {
   int zAplus, zBplus, zEminus;
   u16 *fb;
   u16 color = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x6);
+  u16 cmdpmod = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x4);
+
+  if (cmdpmod & 0x0400) PushUserClipping((cmdpmod >> 9) & 0x1);
 
   v[0].x = (int)Vdp1Regs->localX + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x0C));
   v[1].x = (int)Vdp1Regs->localX + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x10));
@@ -2386,6 +2455,8 @@ void VIDSoftVdp1PolygonDraw(void) {
       }
     }
   }
+
+  if (cmdpmod & 0x0400) PopUserClipping();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -2520,6 +2591,7 @@ void VIDSoftVdp1PolylineDraw(void)
    int X[4];
    int Y[4];
    u16 color;
+   u16 cmdpmod;
 
    X[0] = (int)Vdp1Regs->localX + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x0C));
    Y[0] = (int)Vdp1Regs->localY + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x0E));
@@ -2531,7 +2603,9 @@ void VIDSoftVdp1PolylineDraw(void)
    Y[3] = (int)Vdp1Regs->localY + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x1A));
 
    color = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x6);
-//   CMDPMOD = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x4);
+
+   cmdpmod = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x4);
+   if (cmdpmod & 0x0400) PushUserClipping((cmdpmod >> 9) & 0x1);
 
    if (ClipLine(&X[0], &Y[0], &X[1], &Y[1]))
       DrawLine(X[0], Y[0], X[1], Y[1], color);
@@ -2544,6 +2618,8 @@ void VIDSoftVdp1PolylineDraw(void)
 
    if (ClipLine(&X[3], &Y[3], &X[0], &Y[0]))
       DrawLine(X[3], Y[3], X[0], Y[0], color);
+
+   if (cmdpmod & 0x0400) PopUserClipping();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -2551,16 +2627,20 @@ void VIDSoftVdp1PolylineDraw(void)
 void VIDSoftVdp1LineDraw(void)
 {
    int x1, y1, x2, y2;
+   u16 cmdpmod;
 
    x1 = (int)Vdp1Regs->localX + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x0C));
    y1 = (int)Vdp1Regs->localY + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x0E));
    x2 = (int)Vdp1Regs->localX + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x10));
    y2 = (int)Vdp1Regs->localY + (int)((s16)T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x12));
 
-//   CMDPMOD = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x4);
+   cmdpmod = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x4);
+   if (cmdpmod & 0x0400) PushUserClipping((cmdpmod >> 9) & 0x1);
 
    if (ClipLine(&x1, &y1, &x2, &y2))
       DrawLine(x1, y1, x2, y2, T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x6));
+
+   if (cmdpmod & 0x0400) PopUserClipping();
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -2572,6 +2652,45 @@ void VIDSoftVdp1UserClipping(void)
    Vdp1Regs->userclipX2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x14);
    Vdp1Regs->userclipY2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x16);
 
+#if 0
+   vdp1clipxstart = Vdp1Regs->userclipX1;
+   vdp1clipxend = Vdp1Regs->userclipX2;
+   vdp1clipystart = Vdp1Regs->userclipY1;
+   vdp1clipyend = Vdp1Regs->userclipY2;
+
+   // This needs work
+   if (vdp1clipxstart > Vdp1Regs->systemclipX1)
+      vdp1clipxstart = Vdp1Regs->userclipX1;
+   else
+      vdp1clipxstart = Vdp1Regs->systemclipX1;
+
+   if (vdp1clipxend < Vdp1Regs->systemclipX2)
+      vdp1clipxend = Vdp1Regs->userclipX2;
+   else
+      vdp1clipxend = Vdp1Regs->systemclipX2;
+
+   if (vdp1clipystart > Vdp1Regs->systemclipY1)
+      vdp1clipystart = Vdp1Regs->userclipY1;
+   else
+      vdp1clipystart = Vdp1Regs->systemclipY1;
+
+   if (vdp1clipyend < Vdp1Regs->systemclipY2)
+      vdp1clipyend = Vdp1Regs->userclipY2;
+   else
+      vdp1clipyend = Vdp1Regs->systemclipY2;
+#endif
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+static void PushUserClipping(int mode)
+{
+   if (mode == 1)
+   {
+      VDP1LOG("User clipping mode 1 not implemented\n");
+      return;
+   }
+
    vdp1clipxstart = Vdp1Regs->userclipX1;
    vdp1clipxend = Vdp1Regs->userclipX2;
    vdp1clipystart = Vdp1Regs->userclipY1;
@@ -2601,6 +2720,16 @@ void VIDSoftVdp1UserClipping(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
+static void PopUserClipping(void)
+{
+   vdp1clipxstart = Vdp1Regs->systemclipX1;
+   vdp1clipxend = Vdp1Regs->systemclipX2;
+   vdp1clipystart = Vdp1Regs->systemclipY1;
+   vdp1clipyend = Vdp1Regs->systemclipY2;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 void VIDSoftVdp1SystemClipping(void)
 {
    Vdp1Regs->systemclipX1 = 0;
@@ -2643,9 +2772,6 @@ void VIDSoftVdp2DrawEnd(void)
    int i, i2;
    u16 pixel;
    u8 prioritytable[8];
-   int priority;
-   int shadow;
-   int colorcalc;
    u32 vdp1coloroffset;
    int colormode = Vdp2Regs->SPCTL & 0x20;
    vdp2draw_struct info;
@@ -2730,7 +2856,10 @@ void VIDSoftVdp2DrawEnd(void)
       }
 
       wctl = Vdp2Regs->WCTLC >> 8;
+      clip[0].xstart = clip[0].ystart = clip[0].xend = clip[0].yend = 0;
+      clip[1].xstart = clip[1].ystart = clip[1].xend = clip[1].yend = 0;
       ReadWindowData(wctl, clip);
+      linewnd0addr = linewnd1addr = 0;
       ReadLineWindowData(&islinewindow, wctl, &linewnd0addr, &linewnd1addr);
 
       for (i2 = 0; i2 < vdp2height; i2++)
@@ -2785,6 +2914,10 @@ void VIDSoftVdp2DrawEnd(void)
                else
                {
                   // Color bank
+		  int priority;
+		  int shadow;
+		  int colorcalc;
+		  priority = 0;  // Avoid compiler warning
                   Vdp1ProcessSpritePixel(vdp1spritetype, &pixel, &shadow, &priority, &colorcalc);
                   if (prioritytable[priority] >= Vdp2GetPixelPriority(vdp2src[0]))
                      dst[0] = info.PostPixelFetchCalc(&info, COLSAT2YAB32(0xFF, Vdp2ColorRamGetColor(vdp1coloroffset + pixel)));
@@ -3018,3 +3151,9 @@ void VIDSoftVdp1EraseFrameBuffer(void)
 }
 
 //////////////////////////////////////////////////////////////////////////////
+
+void VIDSoftGetGlSize(int *width, int *height)
+{
+   *width = outputwidth;
+   *height = outputheight;
+}
