@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <windows.h>
@@ -24,12 +24,15 @@
 #include "../vdp1.h"
 #include "../vdp2.h"
 #include "../yui.h"
-#include "settings.h"
+#include "settings/settings.h"
 #include "resource.h"
+#include "../movie.h"
 
 int PERDXInit(void);
 void PERDXDeInit(void);
 int PERDXHandleEvents(void);
+void YuiCaptureVideo(void);
+int Check_Skip_Key();
 
 PerInterface_struct PERDIRECTX = {
 PERCORE_DIRECTX,
@@ -51,23 +54,7 @@ u32 numdevices=0;
 u32 numpads=12;
 PerPad_struct *pad[12];
 padconf_struct paddevice[12];
-
-const char *pad_names[] = {
-"Up",
-"Right",
-"Down",
-"Left",
-"R",
-"L",
-"Start",
-"A",
-"B",
-"C",
-"X",
-"Y",
-"Z",
-NULL
-};
+int porttype[2];
 
 const char *mouse_names[] = {
 "A",
@@ -108,71 +95,11 @@ BOOL CALLBACK EnumPeripheralsCallback (LPCDIDEVICEINSTANCE lpddi, LPVOID pvRef)
 
 //////////////////////////////////////////////////////////////////////////////
 
-int PERDXInit(void)
+void LoadDefaultPort1A(void)
 {
-   DIPROPDWORD dipdw;
-   char tempstr[512];
-   HRESULT ret;
+   porttype[0] = 1;
+   porttype[1] = 0;
 
-   memset(pad, 0, sizeof(pad));
-   memset(paddevice, 0, sizeof(paddevice));
-
-   if ((ret = DirectInput8Create(GetModuleHandle(NULL), DIRECTINPUT_VERSION,
-       &IID_IDirectInput8, (LPVOID *)&lpDI8, NULL)) != DI_OK)
-   {
-      sprintf(tempstr, "DirectInput8Create error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
-      MessageBox (NULL, tempstr, "Error",  MB_OK | MB_ICONINFORMATION);
-      return -1;
-   }
-
-   IDirectInput8_EnumDevices(lpDI8, DI8DEVCLASS_ALL, EnumPeripheralsCallback,
-                      NULL, DIEDFL_ATTACHEDONLY);
-
-   if ((ret = IDirectInput8_CreateDevice(lpDI8, &GUID_SysKeyboard, &lpDIDevice[0],
-       NULL)) != DI_OK)
-   {
-      sprintf(tempstr, "IDirectInput8_CreateDevice error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
-      MessageBox (NULL, tempstr, "Error",  MB_OK | MB_ICONINFORMATION);
-      return -1;
-   }
-
-   if ((ret = IDirectInputDevice8_SetDataFormat(lpDIDevice[0], &c_dfDIKeyboard)) != DI_OK)
-   {
-      sprintf(tempstr, "IDirectInputDevice8_SetDataFormat error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
-      MessageBox (NULL, tempstr, "Error",  MB_OK | MB_ICONINFORMATION);
-      return -1;
-   }
-
-   if ((ret = IDirectInputDevice8_SetCooperativeLevel(lpDIDevice[0], YabWin,
-       DISCL_FOREGROUND | DISCL_NONEXCLUSIVE | DISCL_NOWINKEY)) != DI_OK)
-   {
-      sprintf(tempstr, "IDirectInputDevice8_SetCooperativeLevel error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
-      MessageBox (NULL, tempstr, "Error",  MB_OK | MB_ICONINFORMATION);
-      return -1;
-   }
-
-   dipdw.diph.dwSize = sizeof(DIPROPDWORD);
-   dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
-   dipdw.diph.dwObj = 0;
-   dipdw.diph.dwHow = DIPH_DEVICE;
-   dipdw.dwData = 8; // should be enough
-
-   // Setup Buffered input
-   if ((ret = IDirectInputDevice8_SetProperty(lpDIDevice[0], DIPROP_BUFFERSIZE, &dipdw.diph)) != DI_OK)
-   {
-      sprintf(tempstr, "IDirectInputDevice8_SetProperty error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
-      MessageBox (NULL, tempstr, "Error",  MB_OK | MB_ICONINFORMATION);
-      return -1;
-   }
-
-   // Make sure Keyboard is acquired already
-   IDirectInputDevice8_Acquire(lpDIDevice[0]);
-
-   paddevice[0].lpDIDevice = lpDIDevice[0];
-   paddevice[0].type = TYPE_KEYBOARD;
-   paddevice[0].emulatetype = 1;
-
-   PerPortReset();
    pad[0] = PerPadAdd(&PORTDATA1);
 
    PerSetKey(DIK_UP, PERPAD_UP, pad[0]);
@@ -188,7 +115,76 @@ int PERDXInit(void)
    PerSetKey(DIK_X, PERPAD_LEFT_TRIGGER, pad[0]);
    PerSetKey(DIK_Z, PERPAD_RIGHT_TRIGGER, pad[0]);
    PerSetKey(DIK_J, PERPAD_START, pad[0]);
+}
 
+//////////////////////////////////////////////////////////////////////////////
+
+int PERDXInit(void)
+{
+   DIPROPDWORD dipdw;
+   char tempstr[512];
+   HRESULT ret;
+
+   memset(pad, 0, sizeof(pad));
+   memset(paddevice, 0, sizeof(paddevice));
+
+   if ((ret = DirectInput8Create(GetModuleHandle(NULL), DIRECTINPUT_VERSION,
+       &IID_IDirectInput8, (LPVOID *)&lpDI8, NULL)) != DI_OK)
+   {
+      sprintf(tempstr, "DirectInput8Create error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
+      MessageBox (NULL, _16(tempstr), _16("Error"),  MB_OK | MB_ICONINFORMATION);
+      return -1;
+   }
+
+   IDirectInput8_EnumDevices(lpDI8, DI8DEVCLASS_ALL, EnumPeripheralsCallback,
+                      NULL, DIEDFL_ATTACHEDONLY);
+
+   if ((ret = IDirectInput8_CreateDevice(lpDI8, &GUID_SysKeyboard, &lpDIDevice[0],
+       NULL)) != DI_OK)
+   {
+      sprintf(tempstr, "IDirectInput8_CreateDevice error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
+      MessageBox (NULL, _16(tempstr), _16("Error"),  MB_OK | MB_ICONINFORMATION);
+      return -1;
+   }
+
+   if ((ret = IDirectInputDevice8_SetDataFormat(lpDIDevice[0], &c_dfDIKeyboard)) != DI_OK)
+   {
+      sprintf(tempstr, "IDirectInputDevice8_SetDataFormat error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
+      MessageBox (NULL, _16(tempstr), _16("Error"),  MB_OK | MB_ICONINFORMATION);
+      return -1;
+   }
+
+   if ((ret = IDirectInputDevice8_SetCooperativeLevel(lpDIDevice[0], YabWin,
+       DISCL_FOREGROUND | DISCL_NONEXCLUSIVE | DISCL_NOWINKEY)) != DI_OK)
+   {
+      sprintf(tempstr, "IDirectInputDevice8_SetCooperativeLevel error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
+      MessageBox (NULL, _16(tempstr), _16("Error"),  MB_OK | MB_ICONINFORMATION);
+      return -1;
+   }
+
+   dipdw.diph.dwSize = sizeof(DIPROPDWORD);
+   dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
+   dipdw.diph.dwObj = 0;
+   dipdw.diph.dwHow = DIPH_DEVICE;
+   dipdw.dwData = 8; // should be enough
+
+   // Setup Buffered input
+   if ((ret = IDirectInputDevice8_SetProperty(lpDIDevice[0], DIPROP_BUFFERSIZE, &dipdw.diph)) != DI_OK)
+   {
+      sprintf(tempstr, "IDirectInputDevice8_SetProperty error: %s - %s", DXGetErrorString8(ret), DXGetErrorDescription8(ret));
+      MessageBox (NULL, _16(tempstr), _16("Error"),  MB_OK | MB_ICONINFORMATION);
+      return -1;
+   }
+
+   // Make sure Keyboard is acquired already
+   IDirectInputDevice8_Acquire(lpDIDevice[0]);
+
+   paddevice[0].lpDIDevice = lpDIDevice[0];
+   paddevice[0].type = TYPE_KEYBOARD;
+   paddevice[0].emulatetype = 1;
+
+   PerPortReset();
+   LoadDefaultPort1A();
    return 0;
 }
 
@@ -214,136 +210,210 @@ void PERDXLoadDevices(char *inifilename)
    GUID guid;
    DIDEVCAPS didc;
    u32 i;
-   int i2;
+   int j, i2;
    int buttonid;
    DIPROPDWORD dipdw;
    int id;
    DWORD coopflags=DISCL_FOREGROUND | DISCL_NONEXCLUSIVE;
+   BOOL loaddefault=TRUE;
+   int numpads;
+   HRESULT hr;
 
    if (!PERCore)
       return;
    PerPortReset();
    memset(pad, 0, sizeof(pad));
 
-   for (i = 0; i < numpads; i++)
+   // Check Connection Type
+   if (GetPrivateProfileStringA("Input", "Port1Type", "", tempstr, MAX_PATH, inifilename) == 0)
    {
-      sprintf(string1, "Peripheral%d", (int)i+1);
-
-      // Let's first fetch the guid of the device
-      if (GetPrivateProfileString(string1, "GUID", "", tempstr, MAX_PATH, inifilename) == 0)
-         continue;
-
-      if (GetPrivateProfileString(string1, "EmulateType", "0", string2, MAX_PATH, inifilename))
+      // Check if it's using the old ini settings for peripherals
+      if (GetPrivateProfileStringA("Peripheral1", "GUID", "", tempstr, MAX_PATH, inifilename) != 0)
       {
-         paddevice[i].emulatetype = atoi(string2);
-         if (paddevice[i].emulatetype == 0)
-            continue;
-      }
-
-      if (paddevice[i].lpDIDevice)
-      {
-         // Free the default keyboard, etc.
-         IDirectInputDevice8_Unacquire(paddevice[i].lpDIDevice);
-         IDirectInputDevice8_Release(paddevice[i].lpDIDevice);
-      }
-
-      StringToGUID(tempstr, &guid);
-
-      // Ok, now that we've got the GUID of the device, let's set it up
-      if (IDirectInput8_CreateDevice(lpDI8, &guid, &lpDIDevice[i],
-          NULL) != DI_OK)
-      {
-         paddevice[i].lpDIDevice = NULL;
-         paddevice[i].emulatetype = 0;
-         continue;
-      }
-
-      paddevice[i].lpDIDevice = lpDIDevice[i];
-
-      didc.dwSize = sizeof(DIDEVCAPS);
-
-      if (IDirectInputDevice8_GetCapabilities(lpDIDevice[i], &didc) != DI_OK)
-         continue;
-
-      if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_KEYBOARD)
-      {
-         if (IDirectInputDevice8_SetDataFormat(lpDIDevice[i], &c_dfDIKeyboard) != DI_OK)
-            continue;
-         paddevice[i].type = TYPE_KEYBOARD;
-         coopflags |= DISCL_NOWINKEY;
-      }       
-      else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_GAMEPAD ||
-               GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_JOYSTICK)
-      {
-         if (IDirectInputDevice8_SetDataFormat(lpDIDevice[i], &c_dfDIJoystick2) != DI_OK)
-            continue;
-         paddevice[i].type = TYPE_JOYSTICK;
-      }
-      else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_MOUSE)
-      {
-         if (IDirectInputDevice8_SetDataFormat(lpDIDevice[i], &c_dfDIMouse2) != DI_OK)
-            continue;
-         paddevice[i].type = TYPE_MOUSE;
-         coopflags = DISCL_FOREGROUND | DISCL_EXCLUSIVE;
-      }
-
-
-      if (IDirectInputDevice8_SetCooperativeLevel(lpDIDevice[i], YabWin,
-          coopflags) != DI_OK)
-         continue;
-
-      dipdw.diph.dwSize = sizeof(DIPROPDWORD);
-      dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
-      dipdw.diph.dwObj = 0;
-      dipdw.diph.dwHow = DIPH_DEVICE;
-      dipdw.dwData = 8; // should be enough
-
-      // Setup Buffered input
-      if (IDirectInputDevice8_SetProperty(lpDIDevice[i], DIPROP_BUFFERSIZE, &dipdw.diph) != DI_OK)
-         continue;
-
-      IDirectInputDevice8_Acquire(lpDIDevice[i]);
-
-      switch(paddevice[i].emulatetype)
-      {
-         case 1: // Standard Pad
-            id = PERPAD;
-            break;
-         case 2: // Analog Pad
-         case 3: // Stunner
-         case 5: // Keyboard
-            id = 0;
-            break;
-         case 4: // Mouse
-            id = PERMOUSE;
-            break;
-         default: break;
-      }
-
-      // Make sure we're added to the smpc list
-      if (i < 6)
-         pad[i] = PerAddPeripheral(&PORTDATA1, id);
-      else
-         pad[i] = PerAddPeripheral(&PORTDATA2, id);
-
-      // Now that we're all setup, let's fetch the controls from the ini
-      sprintf(string1, "Peripheral%d", (int)i+1);
-
-      if (paddevice[i].emulatetype != 3 &&
-          paddevice[i].emulatetype != 4)
-      {
-         for (i2 = 0; i2 < 13; i2++)
+         // Convert to the newer type of settings
+         for (i = 0; i < 2; i++)
          {
-            buttonid = GetPrivateProfileInt(string1, pad_names[i2], 0, inifilename);
-            PerSetKey(buttonid, i2, pad[i]);
+            sprintf(string1, "Port%dType", (int)i+1);
+            WritePrivateProfileStringA("Input", string1, "1", inifilename);
+
+            sprintf(string1, "Peripheral%d", (int)i+1);
+            sprintf(string2, "Peripheral%dA", (int)i+1);
+
+            if (GetPrivateProfileStringA(string1, "GUID", "", tempstr, MAX_PATH, inifilename))
+               WritePrivateProfileStringA(string2, "GUID", tempstr, inifilename);
+
+            if (GetPrivateProfileStringA(string1, "EmulateType", "", tempstr, MAX_PATH, inifilename))
+               WritePrivateProfileStringA(string2, "EmulateType", tempstr, inifilename);
+
+            for (i2 = 0; i2 < 13; i2++)
+            {
+               if (GetPrivateProfileStringA(string1, PerPadNames[i2], "", tempstr, MAX_PATH, inifilename))
+                  WritePrivateProfileStringA(string2, PerPadNames[i2], tempstr, inifilename);
+            }
          }
-      }
-      else if (paddevice[i].emulatetype == 4)
-      {
-         for (i2 = 0; i2 < 4; i2++)
+
+         // Remove old ini entries
+         for (i = 0; i < 12; i++)
          {
-            buttonid = GetPrivateProfileInt(string1, mouse_names[i2], 0, inifilename);
-            PerSetKey(buttonid, PERMOUSE_LEFT+i2, pad[i]);
+            sprintf(string1, "Peripheral%d", (int)i+1);
+            WritePrivateProfileStringA(string1, NULL, NULL, inifilename);
+         }
+
+         loaddefault = FALSE;
+      }
+   }
+   else 
+      loaddefault = FALSE;
+
+   if (loaddefault)
+   {
+      LoadDefaultPort1A();
+      return;
+   }
+
+   // Load new type settings
+   for (i = 0; i < 2; i++)
+   {
+      sprintf(string1, "Port%dType", (int)i+1);
+
+      if (GetPrivateProfileStringA("Input", string1, "", tempstr, MAX_PATH, inifilename) != 0)
+      {
+         porttype[i] = atoi(tempstr);
+
+         switch(porttype[i])
+         {
+            case 1:
+               numpads = 1;
+               break;
+            case 2:
+               numpads = 6;
+               break;
+            default:
+               numpads = 0;
+               break;
+         }
+
+         // Load new type settings
+         for (j = 0; j < numpads; j++)
+         {
+            int padindex=(6*i)+j;
+            padconf_struct *curdevice=&paddevice[padindex];
+            sprintf(string1, "Peripheral%d%C", (int)i+1, 'A' + j);
+
+            // Let's first fetch the guid of the device
+            if (GetPrivateProfileStringA(string1, "GUID", "", tempstr, MAX_PATH, inifilename) == 0)
+               continue;
+
+            if (GetPrivateProfileStringA(string1, "EmulateType", "0", string2, MAX_PATH, inifilename))
+            {
+               curdevice->emulatetype = atoi(string2);
+               if (curdevice->emulatetype == 0)
+                  continue;
+            }
+
+            if (curdevice->lpDIDevice)
+            {
+               // Free the default keyboard, etc.
+               IDirectInputDevice8_Unacquire(curdevice->lpDIDevice);
+               IDirectInputDevice8_Release(curdevice->lpDIDevice);
+            }
+
+            StringToGUID(tempstr, &guid);
+
+            // Ok, now that we've got the GUID of the device, let's set it up
+            if (IDirectInput8_CreateDevice(lpDI8, &guid, &lpDIDevice[padindex],
+               NULL) != DI_OK)
+            {
+               curdevice->lpDIDevice = NULL;
+               curdevice->emulatetype = 0;
+               continue;
+            }
+
+            curdevice->lpDIDevice = lpDIDevice[padindex];
+
+            didc.dwSize = sizeof(DIDEVCAPS);
+
+            if (IDirectInputDevice8_GetCapabilities(lpDIDevice[padindex], &didc) != DI_OK)
+               continue;
+
+            if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_KEYBOARD)
+            {
+               if (IDirectInputDevice8_SetDataFormat(lpDIDevice[padindex], &c_dfDIKeyboard) != DI_OK)
+                  continue;
+               curdevice->type = TYPE_KEYBOARD;
+               coopflags |= DISCL_NOWINKEY;
+            }       
+            else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_GAMEPAD ||
+               GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_JOYSTICK)
+            {
+               if (IDirectInputDevice8_SetDataFormat(lpDIDevice[padindex], &c_dfDIJoystick2) != DI_OK)
+                  continue;
+               curdevice->type = TYPE_JOYSTICK;
+            }
+            else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_MOUSE)
+            {
+               if (IDirectInputDevice8_SetDataFormat(lpDIDevice[padindex], &c_dfDIMouse2) != DI_OK)
+                  continue;
+               curdevice->type = TYPE_MOUSE;
+               coopflags = DISCL_FOREGROUND | DISCL_EXCLUSIVE;
+            }
+
+            hr = IDirectInputDevice8_SetCooperativeLevel(lpDIDevice[i], YabWin, coopflags);
+            if (FAILED(hr))
+               continue;
+
+            dipdw.diph.dwSize = sizeof(DIPROPDWORD);
+            dipdw.diph.dwHeaderSize = sizeof(DIPROPHEADER);
+            dipdw.diph.dwObj = 0;
+            dipdw.diph.dwHow = DIPH_DEVICE;
+            dipdw.dwData = 8; // should be enough
+
+            // Setup Buffered input
+            if (IDirectInputDevice8_SetProperty(lpDIDevice[padindex], DIPROP_BUFFERSIZE, &dipdw.diph) != DI_OK)
+               continue;
+
+            IDirectInputDevice8_Acquire(lpDIDevice[padindex]);
+
+            switch(curdevice->emulatetype)
+            {
+               case 1: // Standard Pad
+                  id = PERPAD;
+                  break;
+               case 2: // Analog Pad
+               case 3: // Stunner
+               case 5: // Keyboard
+                  id = 0;
+                  break;
+               case 4: // Mouse
+                  id = PERMOUSE;
+                  break;
+               default: break;
+            }
+
+            // Make sure we're added to the smpc list
+            if (i == 0)
+               pad[padindex] = PerAddPeripheral(&PORTDATA1, id);
+            else
+               pad[padindex] = PerAddPeripheral(&PORTDATA2, id);
+
+            // Now that we're all setup, let's fetch the controls from the ini
+            if (curdevice->emulatetype != 3 &&
+               curdevice->emulatetype != 4)
+            {
+               for (i2 = 0; i2 < 13; i2++)
+               {
+                  buttonid = GetPrivateProfileIntA(string1, PerPadNames[i2], 0, inifilename);
+                  PerSetKey(buttonid, i2, pad[padindex]);
+               }
+            }
+            else if (curdevice->emulatetype == 4)
+            {
+               for (i2 = 0; i2 < 4; i2++)
+               {
+                  buttonid = GetPrivateProfileIntA(string1, mouse_names[i2], 0, inifilename);
+                  PerSetKey(buttonid, PERMOUSE_LEFT+i2, pad[padindex]);
+               }
+            }
          }
       }
    }
@@ -570,18 +640,69 @@ void PollKeys(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
+int FrameAdvanceKeyDown=0;
+static DWORD tgtime;
+
 int PERDXHandleEvents(void)
 {
    PollKeys();
 
+   	if (Check_Skip_Key())
+	{
+		FrameAdvanceVariable = NeedAdvance;
+		tgtime = timeGetTime();
+	}
+
    if (YabauseExec() != 0)
       return -1;
 
+   Update_RAM_Watch();
+   YuiCaptureVideo();
+
    return 0;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
+int SkipKeyIsPressed=0;
+int DelayFactor = 5;
+
+int Check_Skip_Key()
+{
+	static time_t lastSkipTime = 0;
+	const int skipPressedNew = FrameAdvanceKeyDown;
+	static int checks = 0;
+
+	if(GetAsyncKeyState(VK_SPACE) & 0x8000)
+		FrameAdvanceKeyDown=1;
+	else
+		FrameAdvanceKeyDown=0;
+	
+	if(skipPressedNew && timeGetTime()-lastSkipTime >= 5)
+	{
+		checks++;
+		if(checks > 8000 + 60)
+			checks -= 8000;
+		lastSkipTime = timeGetTime();
+	}
+
+	if(skipPressedNew && (!SkipKeyIsPressed || ((checks > 60) && ((checks % DelayFactor) == 0))))
+	{
+		SkipKeyIsPressed=1;
+		return 1;
+	}
+	else {
+		if(!skipPressedNew && SkipKeyIsPressed)
+		{
+			SkipKeyIsPressed=0;
+			checks=0;
+		}
+		return 0;
+	}
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 BOOL CALLBACK EnumPeripheralsCallbackGamepad (LPCDIDEVICEINSTANCE lpddi, LPVOID pvRef)
 {
    if (GET_DIDEVICE_TYPE(lpddi->dwDevType) == DI8DEVTYPE_GAMEPAD ||
@@ -637,7 +758,7 @@ void PERDXListDevices(HWND control, int emulatetype)
    numguids = 0;
 
    SendMessage(control, CB_RESETCONTENT, 0, 0);
-   SendMessage(control, CB_ADDSTRING, 0, (LPARAM)"None");
+   SendMessage(control, CB_ADDSTRING, 0, (LPARAM)_16("None"));
 
    switch(emulatetype)
    {
@@ -675,7 +796,7 @@ void ConvertKBIDToName(int buttonid, char *string)
    if (buttonid & 0x80)
       buttonid += 0x80;
 
-   GetKeyNameText(buttonid << 16, string, MAX_PATH);
+   GetKeyNameTextA(buttonid << 16, string, MAX_PATH);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -731,17 +852,16 @@ int PERDXInitControlConfig(HWND hWnd, u8 padnum, int *controlmap, const char *in
    char string1[20];
    GUID guid;
    u32 i;
-   int idlist[] = { IDC_UPTEXT, IDC_DOWNTEXT, IDC_LEFTTEXT, IDC_RIGHTTEXT,
+   int idlist[] = { IDC_UPTEXT, IDC_RIGHTTEXT, IDC_DOWNTEXT, IDC_LEFTTEXT,
+                    IDC_RTEXT, IDC_LTEXT, IDC_STARTTEXT,
                     IDC_ATEXT, IDC_BTEXT, IDC_CTEXT,
-                    IDC_XTEXT, IDC_YTEXT, IDC_ZTEXT,
-                    IDC_LTEXT, IDC_RTEXT, IDC_STARTTEXT
+                    IDC_XTEXT, IDC_YTEXT, IDC_ZTEXT
                   };
 
-
-   sprintf(string1, "Peripheral%d", padnum+1);
+   sprintf(string1, "Peripheral%d%C", ((padnum/6)+1), 'A'+(padnum%6));
 
    // Let's first fetch the guid of the device and see if we can get a match
-   if (GetPrivateProfileString(string1, "GUID", "", tempstr, MAX_PATH, inifilename) == 0)
+   if (GetPrivateProfileStringA(string1, "GUID", "", tempstr, MAX_PATH, inifilename) == 0)
    {
       if (padnum == 0)
       {
@@ -749,22 +869,22 @@ int PERDXInitControlConfig(HWND hWnd, u8 padnum, int *controlmap, const char *in
          SendDlgItemMessage(hWnd, IDC_DXDEVICECB, CB_SETCURSEL, 1, 0);
 
          controlmap[0] = DIK_UP;
-         controlmap[1] = DIK_DOWN;
-         controlmap[2] = DIK_LEFT;
-         controlmap[3] = DIK_RIGHT;
-         controlmap[4] = DIK_K;
-         controlmap[5] = DIK_L;
-         controlmap[6] = DIK_M;
-         controlmap[7] = DIK_U;
-         controlmap[8] = DIK_I;
-         controlmap[9] = DIK_O;
-         controlmap[10] = DIK_X;
-         controlmap[11] = DIK_Z;
-         controlmap[12] = DIK_J;
+         controlmap[1] = DIK_RIGHT;
+         controlmap[2] = DIK_DOWN;
+         controlmap[3] = DIK_LEFT;
+         controlmap[4] = DIK_Z;
+         controlmap[5] = DIK_X;
+         controlmap[6] = DIK_J;
+         controlmap[7] = DIK_K;
+         controlmap[8] = DIK_L;
+         controlmap[9] = DIK_M;
+         controlmap[10] = DIK_U;
+         controlmap[11] = DIK_I;
+         controlmap[12] = DIK_O;
          for (i = 0; i < 13; i++)
          {
             ConvertKBIDToName(controlmap[i], tempstr);
-            SetDlgItemText(hWnd, idlist[i], tempstr);
+            SetDlgItemText(hWnd, idlist[i], _16(tempstr));
          }
       }
       else
@@ -814,37 +934,38 @@ int PERDXInitControlConfig(HWND hWnd, u8 padnum, int *controlmap, const char *in
 
       if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_KEYBOARD)
       {
-         sprintf(string1, "Peripheral%d", padnum+1);
+         sprintf(string1, "Peripheral%d%C", ((padnum/6)+1), 'A'+(padnum%6));
 
          for (i = 0; i < 13; i++)
          {
-            buttonid = GetPrivateProfileInt(string1, pad_names[i], 0, inifilename);
+            buttonid = GetPrivateProfileIntA(string1, PerPadNames[i], 0, inifilename);
+            printf("%2d: %d\n", i, buttonid);
             controlmap[i] = buttonid;
             ConvertKBIDToName(buttonid, tempstr);
-            SetDlgItemText(hWnd, idlist[i], tempstr);
+            SetDlgItemText(hWnd, idlist[i], _16(tempstr));
          }
       }       
       else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_GAMEPAD ||
               GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_JOYSTICK)
       {
-         sprintf(string1, "Peripheral%d", padnum+1);
+         sprintf(string1, "Peripheral%d%C", ((padnum/6)+1), 'A'+(padnum%6));
 
          for (i = 0; i < 13; i++)
          {
-            buttonid = GetPrivateProfileInt(string1, pad_names[i], 0, inifilename);
+            buttonid = GetPrivateProfileIntA(string1, PerPadNames[i], 0, inifilename);
             controlmap[i] = buttonid;
             ConvertJoyIDToName(buttonid, tempstr);
-            SetDlgItemText(hWnd, idlist[i], tempstr);
+            SetDlgItemText(hWnd, idlist[i], _16(tempstr));
          }
       }
       else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_MOUSE)
       {
          for (i = 0; i < 13; i++)
          {
-            buttonid = GetPrivateProfileInt(string1, pad_names[i], 0, inifilename);
+            buttonid = GetPrivateProfileIntA(string1, PerPadNames[i], 0, inifilename);
             controlmap[i] = buttonid;
             ConvertMouseIDToName(buttonid, tempstr);
-            SetDlgItemText(hWnd, idlist[i], tempstr);
+            SetDlgItemText(hWnd, idlist[i], _16(tempstr));
          }
       }
 
@@ -930,7 +1051,7 @@ int PERDXFetchNextPress(HWND hWnd, u32 guidnum, char *buttonname)
          if (buttonid & 0x80)
             buttonid += 0x80;
 
-         GetKeyNameText(buttonid << 16, buttonname, MAX_PATH);
+         GetKeyNameTextA(buttonid << 16, buttonname, MAX_PATH);
          buttonid = nextpress.dwOfs;
       }
       else if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_GAMEPAD ||
@@ -1195,13 +1316,13 @@ LRESULT CALLBACK ButtonConfigDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
 
 //////////////////////////////////////////////////////////////////////////////
 
-BOOL PERDXWriteGUID(u32 guidnum, u8 padnum, LPCTSTR inifilename)
+BOOL PERDXWriteGUID(u32 guidnum, u8 padnum, LPCSTR inifilename)
 {
    char string1[20];
    char string2[40];
-   sprintf(string1, "Peripheral%d", padnum+1);
+   sprintf(string1, "Peripheral%d%C", ((padnum/6)+1), 'A'+(padnum%6));
    sprintf(string2, "%08X-%04X-%04X-%02X%02X%02X%02X%02X%02X%02X%02X", (int)GUIDDevice[guidnum].Data1, (int)GUIDDevice[guidnum].Data2, (int)GUIDDevice[guidnum].Data3, (int)GUIDDevice[guidnum].Data4[0], (int)GUIDDevice[guidnum].Data4[1], (int)GUIDDevice[guidnum].Data4[2], (int)GUIDDevice[guidnum].Data4[3], (int)GUIDDevice[guidnum].Data4[4], (int)GUIDDevice[guidnum].Data4[5], (int)GUIDDevice[guidnum].Data4[6], (int)GUIDDevice[guidnum].Data4[7]);
-   return WritePrivateProfileString(string1, "GUID", string2, inifilename);
+   return WritePrivateProfileStringA(string1, "GUID", string2, inifilename);
 }
 
 //////////////////////////////////////////////////////////////////////////////
