@@ -40,6 +40,39 @@
 #define IDD_VDP2VIEWER                  134
 #define IDD_PADCONFIG1                  135
 #define IDD_MOUSECONFIG                 135
+#define MENU_RECORD_MOVIE               141
+#define MENU_PLAY_MOVIE                 142
+#define MENU_STOP_MOVIE                 143
+#define IDC_WATCHLIST 900
+#define IDC_PROMPT_EDIT 901
+#define IDC_1_BYTE 902
+#define IDC_2_BYTES 903
+#define IDC_4_BYTES 904
+#define IDC_SIGNED	905
+#define IDC_HEX 906
+#define IDC_EDIT_COMPAREADDRESS 907
+#define IDC_UNSIGNED 908
+#define ID_WATCHES_UPDOWN 909
+#define RAMMENU_FILE_AUTOLOAD 910
+#define RAMMENU_FILE_SAVEWINDOW 911
+#define RAMMENU_FILE_RECENT 912
+#define RAMMENU_FILE_SAVE 913
+#define RAMMENU_FILE_SAVEAS 914
+#define RAMMENU_FILE_OPEN 915
+#define RAMMENU_FILE_APPEND 916
+#define RAMMENU_FILE_NEW 917
+#define IDC_C_WATCH_REMOVE 918
+#define IDC_C_WATCH_EDIT 919
+#define IDD_EDITWATCH 920
+#define IDC_C_WATCH 921
+#define IDC_C_WATCH_DUPLICATE 922
+#define IDC_C_WATCH_UP 923
+#define IDC_C_WATCH_DOWN 924
+#define IDC_C_ADDCHEAT 925
+#define ID_RAM_WATCH 926
+#define IDD_RAMWATCH 927
+#define IDC_SPECIFICADDRESS 928
+#define IDC_PROMPT_TEXT 929
 #define IDC_EDITTEXT1                   1001
 #define IDC_DISCTYPECB                  1001
 #define IDC_VIDEOCORECB                 1001
@@ -148,56 +181,56 @@
 #define IDC_DISPENABCB                  1011
 #define IDC_CHECKBOX5                   1012
 #define IDC_MPEGROMBROWSE               1012
-#define IDC_DOWNPB                      1012
+#define IDC_RIGHTPB                     1012
 #define IDC_BUPDATASIZEET               1012
 #define IDC_CODEADDR                    1012
 #define IDC_CARTTYPECB                  1013
-#define IDC_LEFTPB                      1013
+#define IDC_DOWNPB                      1013
 #define IDC_BUPBLOCKSIZEET              1013
 #define IDC_CODEVAL                     1013
 #define IDC_CARTEDIT                    1014
-#define IDC_RIGHTPB                     1014
+#define IDC_LEFTPB                      1014
 #define IDC_VDP2GENET                   1014
 #define IDC_CARTBROWSE                  1015
-#define IDC_APB                         1015
+#define IDC_RPB                         1015
 #define IDC_CTENABLE                    1015
 #define IDC_8BITRB                      1015
-#define IDC_BPB                         1016
+#define IDC_LPB                         1016
 #define IDC_CTBYTEWRITE                 1016
 #define IDC_16BITRB                     1016
-#define IDC_CPB                         1017
+#define IDC_STARTPB                     1017
 #define IDC_CTWORDWRITE                 1017
 #define IDC_32BITRB                     1017
-#define IDC_XPB                         1018
+#define IDC_APB                         1018
 #define IDC_CTLONGWRITE                 1018
-#define IDC_YPB                         1019
+#define IDC_BPB                         1019
 #define IDC_STATUSBAR                   1020
 #define IDC_SETTINGSTAB                 1020
-#define IDC_ZPB                         1020
+#define IDC_CPB                         1020
 #define IDC_CHEATSEARCHET               1020
-#define IDC_LPB                         1021
+#define IDC_XPB                         1021
 #define IDC_CTSEARCHRESTARTBT           1021
-#define IDC_RPB                         1022
+#define IDC_YPB                         1022
 #define IDC_CTSEARCHBT                  1022
-#define IDC_STARTPB                     1023
+#define IDC_ZPB                         1023
 #define IDC_CTADDCHEATBT                1023
 #define IDC_UPTEXT                      1024
 #define IDC_STEP                        1025
-#define IDC_DOWNTEXT                    1025
+#define IDC_RIGHTTEXT                   1025
 #define IDC_STEPOVER                    1026
-#define IDC_LEFTTEXT                    1026
+#define IDC_DOWNTEXT                    1026
 #define IDC_MEMTRANSFER                 1027
-#define IDC_RIGHTTEXT                   1027
+#define IDC_LEFTTEXT                    1027
 #define IDC_MEMEDITOR                   1028
-#define IDC_ATEXT                       1028
-#define IDC_BTEXT                       1029
-#define IDC_CTEXT                       1030
-#define IDC_XTEXT                       1031
-#define IDC_YTEXT                       1032
-#define IDC_ZTEXT                       1033
-#define IDC_LTEXT                       1034
-#define IDC_RTEXT                       1035
-#define IDC_STARTTEXT                   1036
+#define IDC_RTEXT                       1028
+#define IDC_LTEXT                       1029
+#define IDC_STARTTEXT                   1030
+#define IDC_ATEXT                       1031
+#define IDC_BTEXT                       1032
+#define IDC_CTEXT                       1033
+#define IDC_XTEXT                       1034
+#define IDC_YTEXT                       1035
+#define IDC_ZTEXT                       1036
 #define IDC_CUSTOMCANCEL                1037
 #define IDC_ADDBP1                      1040
 #define IDC_DELBP1                      1041
@@ -254,9 +287,19 @@
 #define IDC_SAVETOFILE                  1107
 #define IDC_VDP2VIEWER                  1107
 #define IDC_VDP2SAVEBMPBT               1107
+#define IDC_MINI18NBROWSE               1107
+#define IDC_MINI18NLOGBROWSE            1107
+#define IDC_SAVEPROGRAM                 1107
 #define IDC_VDP2SCREENCB                1108
 #define IDC_VDP2TEXTET                  1109
 #define IDC_VDP1SAVEBMPBT               1110
+#define IDC_USEMINI18NLOG               1111
+#define IDC_MINI18NLOGFILENAME          1112
+#define IDC_SAVEMD0                     1114
+#define IDC_SAVEMD1                     1115
+#define IDC_SAVEMD2                     1116
+#define IDC_BUTTON5                     1117
+#define IDC_SAVEMD3                     1117
 #define IDM_CHOOSEBIOS                  40001
 #define IDM_CHOOSECDROM                 40002
 #define IDM_MEMTRANSFER                 40004
@@ -268,6 +311,8 @@
 #define IDM_SAVESTATEAS                 40010
 #define IDM_LOADSTATEAS                 40011
 #define IDM_EXIT                        40012
+#define IDM_FILE_RECORDAVI              40015
+#define IDM_FILE_STOPAVI                40016
 #define IDM_CHEATSEARCH                 40020
 #define IDM_CHEATLIST                   40021
 #define IDM_MSH2DEBUG                   40030
@@ -316,15 +361,26 @@
 #define IDC_INPUTREGLB                  40082
 #define IDC_OUTPUTREGLB                 40083
 #define IDC_SMPCSTATUSET                40084
+#define ID_FILE_LANGUAGE                40085
+#define IDM_GERMAN                      40086
+#define IDM_ENGLISH                     40087
+#define IDM_FRENCH                      40088
+#define IDM_ITALIAN                     40089
+#define IDM_PORTUGUESE                  40090
+#define IDM_PORTUGUESEBRAZIL            40091
+#define IDM_SWEDISH                     40092
+#define IDM_SPANISH                     40093
+#define IDM_FRAMEADVANCEPAUSE           40096
+#define IDM_TOGGLEREADONLY				40098
 #define IDC_STATIC                      -1
 
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        135
-#define _APS_NEXT_COMMAND_VALUE         40085
-#define _APS_NEXT_CONTROL_VALUE         1111
+#define _APS_NEXT_RESOURCE_VALUE        138
+#define _APS_NEXT_COMMAND_VALUE         40103
+#define _APS_NEXT_CONTROL_VALUE         1118
 #define _APS_NEXT_SYMED_VALUE           133
 #endif
 #endif
