@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 #include <windows.h>
 #include <commctrl.h>
@@ -32,7 +32,7 @@
 #include "perdx.h"
 #include "../cs0.h"
 #include "resource.h"
-#include "settings.h"
+#include "settings/settings.h"
 #include "cd.h"
 #include "../debug.h"
 #include "cheats.h"
@@ -41,9 +41,11 @@
 #include "../m68kc68k.h"
 #endif
 //#include "../m68khle.h"
-#include "yuidebug.h"
+#include "cpudebug/yuidebug.h"
 #include "disasm.h"
 #include "hexedit.h"
+#include "../movie.h"
+#include "ramwatch.h"
 
 #define DONT_PROFILE
 #include "../profile.h"
@@ -66,20 +68,35 @@ HGLRC YabHRC=NULL;
 BOOL isfullscreenset=FALSE;
 int yabwinx = 0;
 int yabwiny = 0;
+psp_struct settingspsp;
 
+int oldbpp = 0;
 static int redsize = 0;
 static int greensize = 0;
 static int bluesize = 0;
 static int depthsize = 0;
 
-char yssfilename[MAX_PATH] = "\0";
+int AVIRecording = 0;
+
+TCHAR yssfilename[MAX_PATH] = TEXT("\0");
 char ysspath[MAX_PATH] = "\0";
+
+TCHAR avifilename[MAX_PATH] = TEXT("\0");
+char avipath[MAX_PATH] = "\0";
+
+TCHAR ymvfilename[MAX_PATH] = TEXT("\0");
+char ymvpath[MAX_PATH] = "\0";
+
 char netlinksetting[80];
-char bmpfilename[MAX_PATH] = "\0";
+TCHAR bmpfilename[MAX_PATH] = TEXT("\0");
 
 LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam);
 void YuiReleaseVideo(void);
 
+int DRV_AviBegin(const char* fname, HWND HWnd);
+void DRV_AviVideoUpdate(const u16* buffer, HWND HWnd);
+void DRV_AviEnd();
+
 SH2Interface_struct *SH2CoreList[] = {
 &SH2Interpreter,
 &SH2DebugInterpreter,
@@ -117,6 +134,9 @@ M68K_struct *M68KCoreList[] = {
 #ifndef NOC68K
 &M68KC68K,
 #endif
+#ifdef HAVE_Q68
+&M68KQ68,
+#endif
 //&M68KHLE,
 NULL
 };
@@ -168,7 +188,8 @@ int YuiSetVideoMode(int width, int height, int bpp, int fullscreen)
    }
 
    // Make sure any previously setup variables are released
-   YuiReleaseVideo();
+   if (oldbpp != bpp)
+      YuiReleaseVideo();
 
    if (fullscreen)
    {
@@ -227,44 +248,48 @@ int YuiSetVideoMode(int width, int height, int bpp, int fullscreen)
    }
 
    // Get the Device Context for our window
-   if ((YabHDC = GetDC(YabWin)) == NULL)
+   if (oldbpp != bpp)
    {
-      YuiReleaseVideo();
-      return -1;
-   }
+      if ((YabHDC = GetDC(YabWin)) == NULL)
+      {
+         YuiReleaseVideo();
+         return -1;
+      }
 
-   // Let's setup the Pixel format for the context
-   memset(&pfd, 0, sizeof(PIXELFORMATDESCRIPTOR));
-   pfd.nSize = sizeof(PIXELFORMATDESCRIPTOR);
-   pfd.nVersion = 1;
-   pfd.dwFlags = PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL | PFD_DOUBLEBUFFER;
-   pfd.iPixelType = PFD_TYPE_RGBA;
-   pfd.cColorBits = bpp;
-   pfd.cRedBits = redsize;
-   pfd.cGreenBits = greensize;
-   pfd.cBlueBits = bluesize;
-   pfd.cAlphaBits = 0;
-   pfd.cAccumRedBits = 0;
-   pfd.cAccumGreenBits = 0;
-   pfd.cAccumBlueBits = 0;
-   pfd.cAccumAlphaBits = 0;
-   pfd.cAccumBits = pfd.cAccumRedBits + pfd.cAccumGreenBits +
-                    pfd.cAccumBlueBits + pfd.cAccumAlphaBits;
-   pfd.cDepthBits = depthsize;
-   pfd.cStencilBits = 0;
+      // Let's setup the Pixel format for the context
 
-   SetPixelFormat(YabHDC, ChoosePixelFormat(YabHDC, &pfd), &pfd);
+      memset(&pfd, 0, sizeof(PIXELFORMATDESCRIPTOR));
+      pfd.nSize = sizeof(PIXELFORMATDESCRIPTOR);
+      pfd.nVersion = 1;
+      pfd.dwFlags = PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL | PFD_DOUBLEBUFFER;
+      pfd.iPixelType = PFD_TYPE_RGBA;
+      pfd.cColorBits = bpp;
+      pfd.cRedBits = redsize;
+      pfd.cGreenBits = greensize;
+      pfd.cBlueBits = bluesize;
+      pfd.cAlphaBits = 0;
+      pfd.cAccumRedBits = 0;
+      pfd.cAccumGreenBits = 0;
+      pfd.cAccumBlueBits = 0;
+      pfd.cAccumAlphaBits = 0;
+      pfd.cAccumBits = pfd.cAccumRedBits + pfd.cAccumGreenBits +
+         pfd.cAccumBlueBits + pfd.cAccumAlphaBits;
+      pfd.cDepthBits = depthsize;
+      pfd.cStencilBits = 0;
 
-   if ((YabHRC = wglCreateContext(YabHDC)) == NULL)
-   {
-      YuiReleaseVideo();
-      return -1;
-   }
+      SetPixelFormat(YabHDC, ChoosePixelFormat(YabHDC, &pfd), &pfd);
 
-   if(wglMakeCurrent(YabHDC,YabHRC) == FALSE)
-   {
-      YuiReleaseVideo();
-      return -1;
+      if ((YabHRC = wglCreateContext(YabHDC)) == NULL)
+      {
+         YuiReleaseVideo();
+         return -1;
+      }
+
+      if(wglMakeCurrent(YabHDC,YabHRC) == FALSE)
+      {
+         YuiReleaseVideo();
+         return -1;
+      }
    }
 
    ShowWindow(YabWin,SW_SHOW);
@@ -280,6 +305,7 @@ int YuiSetVideoMode(int width, int height, int bpp, int fullscreen)
 
    screenwidth = width;
    screenheight = height;
+   oldbpp = bpp;
 
    return 0;
 }
@@ -380,6 +406,29 @@ int YuiCaptureScreen(const char *filename)
 
 //////////////////////////////////////////////////////////////////////////////
 
+void YuiCaptureVideo(void)
+{
+	u8 *buf;
+	int totalsize=screenwidth * screenheight * sizeof(u32);
+
+	if(AVIRecording == 0)
+		return;
+
+	if ((buf = (u8 *)malloc(totalsize)) == NULL)
+	{
+		return;
+	}
+
+	SwapBuffers(YabHDC);
+	glReadBuffer(GL_BACK);
+	glReadPixels(0, 0, screenwidth, screenheight, GL_RGBA, GL_UNSIGNED_BYTE, buf);
+	SwapBuffers(YabHDC);
+
+	DRV_AviVideoUpdate(buf, YabWin);
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 void YuiPause()
 {
 #ifdef USETHREADS
@@ -443,7 +492,7 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
    yabauseinit_struct yinit;
    int ret;
 
-//YabauseSetup:
+YabauseSetup:
    memset(&yinit, 0, sizeof(yabauseinit_struct));
    yinit.percoretype = percoretype;
    yinit.sh2coretype = sh2coretype;
@@ -474,24 +523,23 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
 
    if ((ret = YabauseInit(&yinit)) < 0)
    {
-/*
       if (ret == -2)
       {
          nocorechange = 1;
 
-         if (DialogBox(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_SETTINGS), NULL, (DLGPROC)SettingsDlgProc) != TRUE)
+         // Startup Settings Configuration
+         ret = (int)SettingsCreatePropertySheets(NULL, TRUE, &settingspsp);
+
+         free(settingspsp.psp);
+         memset(&settingspsp, 0, sizeof(settingspsp));
+
+         if (ret == TRUE)
          {
-            // exit program with error
-            MessageBox (NULL, "yabause.ini must be properly setup before program can be used.", "Error",  MB_OK | MB_ICONINFORMATION);
-            return -1;
+            YabauseDeInit();
+            goto YabauseSetup;
          }
-
-         YuiReleaseVideo();
-         YabauseDeInit();
-
-         goto YabauseSetup;
       }
-*/
+      PostMessage(YabWin, WM_CLOSE, 0, 0);
       return -1;
    }
 
@@ -538,18 +586,24 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
                Cs2ChangeCDCore(CDCORE_SPTI, cdrompath);
             else
                Cs2ChangeCDCore(CDCORE_ISO, cdrompath);
-            MessageBox (NULL, "Changed cd core", "Notice",  MB_OK | MB_ICONINFORMATION);
          }
          else if (changecore & 0x2)
          {
+            int coretype=vidcoretype;
+            corechanged=1;
             VideoChangeCore(vidcoretype);
-            MessageBox (NULL, "Changed video core", "Notice",  MB_OK | MB_ICONINFORMATION);
+            Sleep(0);
+            if (VIDCore && !VIDCore->IsFullscreen())
+            {
+               if (usecustomwindowsize)
+                  VIDCore->Resize(windowwidth, windowheight, 0);
+               else
+                  VIDCore->Resize(320, 224, 0);
+            }
          }
          else if (changecore & 0x4)
-         {
             ScspChangeSoundCore(sndcoretype);
-            MessageBox (NULL, "Changed sound core", "Notice",  MB_OK | MB_ICONINFORMATION);
-         }
+         
 
          changecore = 0;
          corechanged = 1;
@@ -559,6 +613,7 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
 
       Sleep(300);
    }
+   return 0;
 }
 #endif
 
@@ -566,15 +621,15 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
 
 void YuiPrintUsage()
 {
-   MessageBox (NULL, "Usage: yabause [OPTIONS]...\n"
+   MessageBox (NULL, _16("Usage: yabause [OPTIONS]...\n"
                      "-h\t\t--help\t\t\tPrint help and exit\n"
                      "-b STRING\t--bios=STRING\t\tbios file\n"
                      "-i STRING\t\t--iso=STRING\t\tiso/cue file\n"
                      "-c STRING\t--cdrom=STRING\t\tcdrom path\n"
                      "-ns\t\t--nosound\t\tturn sound off\n"
                      "-f\t\t--fullscreen\t\tstart in fullscreen mode\n"
-                     "\t\t--binary=STRING:ADDRESS\tLoad binary file to address",
-                     "Command line usage",  MB_OK | MB_ICONINFORMATION);
+                     "\t\t--binary=STRING:ADDRESS\tLoad binary file to address"),
+                     _16("Command line usage"),  MB_OK | MB_ICONINFORMATION);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -660,7 +715,7 @@ int YuiInit(LPSTR lpCmdLine)
    y_hInstance = GetModuleHandle(NULL);
 
    // get program pathname
-   inifilenamesize = GetModuleFileName(y_hInstance, inifilename, MAX_PATH);
+   inifilenamesize = GetModuleFileNameA(y_hInstance, inifilename, MAX_PATH);
 
    // set pointer to start of extension
 
@@ -712,30 +767,34 @@ int YuiInit(LPSTR lpCmdLine)
    free(cmddup);
 #endif
 
-   if (GetPrivateProfileString("General", "CDROMDrive", "", cdrompath, MAX_PATH, inifilename) == 0)
+   if (GetPrivateProfileStringA("General", "CDROMDrive", "", cdrompath, MAX_PATH, inifilename) == 0)
    {
       if (forcecdpath)
       {
          nocorechange = 1;
 
+         ret = (int)SettingsCreatePropertySheets(NULL, TRUE, &settingspsp);
+         free(settingspsp.psp);
+         memset(&settingspsp, 0, sizeof(settingspsp));
+
          // Startup Settings Configuration
-         if (DialogBox(y_hInstance, MAKEINTRESOURCE(IDD_SETTINGS), NULL, (DLGPROC)SettingsDlgProc) != TRUE)
+         if (ret != TRUE)
          {
             // exit program with error
-            MessageBox (NULL, "yabause.ini must be properly setup before program can be used.", "Error",  MB_OK | MB_ICONINFORMATION);
+            MessageBox (NULL, _16("yabause.ini must be properly setup before program can be used."), _16("Error"),  MB_OK | MB_ICONINFORMATION);
             return -1;
          }
       }
    }
 
-   GetPrivateProfileString("General", "BiosPath", "", biosfilename, MAX_PATH, inifilename);
-   GetPrivateProfileString("General", "BackupRamPath", "bkram.bin", backupramfilename, MAX_PATH, inifilename);
-   GetPrivateProfileString("General", "MpegRomPath", "", mpegromfilename, MAX_PATH, inifilename);
-   GetPrivateProfileString("General", "StatePath", "", ysspath, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "BiosPath", "", biosfilename, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "BackupRamPath", "bkram.bin", backupramfilename, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "MpegRomPath", "", mpegromfilename, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "StatePath", "", ysspath, MAX_PATH, inifilename);
    if (strcmp(ysspath, "") == 0)
-      GetCurrentDirectory(MAX_PATH, ysspath);
+      GetCurrentDirectoryA(MAX_PATH, ysspath);
 
-   GetPrivateProfileString("General", "CartType", "", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "CartType", "", tempstr, MAX_PATH, inifilename);
 
    // figure out cart type here, grab cartfilename if necessary
    carttype = atoi(tempstr);
@@ -748,20 +807,20 @@ int YuiInit(LPSTR lpCmdLine)
       case CART_BACKUPRAM16MBIT:
       case CART_BACKUPRAM32MBIT:
       case CART_ROM16MBIT:
-         GetPrivateProfileString("General", "CartPath", "", cartfilename, MAX_PATH, inifilename);
+         GetPrivateProfileStringA("General", "CartPath", "", cartfilename, MAX_PATH, inifilename);
          break;
       default: break;
    }
 
    // Grab Bios Language Settings
-//   GetPrivateProfileString("General", "BiosLanguage", "", tempstr, MAX_PATH, inifilename);
+//   GetPrivateProfileStringA("General", "BiosLanguage", "", tempstr, MAX_PATH, inifilename);
 
    // Grab SH2 Core Settings
-   GetPrivateProfileString("General", "SH2Core", "", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "SH2Core", "", tempstr, MAX_PATH, inifilename);
    sh2coretype = atoi(tempstr);
 
    // Grab Region Settings
-   GetPrivateProfileString("General", "Region", "", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "Region", "", tempstr, MAX_PATH, inifilename);
 
    if (strlen(tempstr) == 1)
    {
@@ -798,67 +857,67 @@ int YuiInit(LPSTR lpCmdLine)
       regionid = 0;
 
    // Grab Video Core Settings
-   GetPrivateProfileString("Video", "VideoCore", "-1", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "VideoCore", "-1", tempstr, MAX_PATH, inifilename);
    vidcoretype = atoi(tempstr);
    if (vidcoretype == -1)
       vidcoretype = VIDCORE_OGL;
 
    // Grab Auto Frameskip Settings
-   GetPrivateProfileString("Video", "AutoFrameSkip", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "AutoFrameSkip", "0", tempstr, MAX_PATH, inifilename);
    enableautofskip = atoi(tempstr);
 
    // Grab Full Screen Settings
-   GetPrivateProfileString("Video", "UseFullScreenOnStartup", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "UseFullScreenOnStartup", "0", tempstr, MAX_PATH, inifilename);
    usefullscreenonstartup = atoi(tempstr);
 
-   GetPrivateProfileString("Video", "FullScreenWidth", "640", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "FullScreenWidth", "640", tempstr, MAX_PATH, inifilename);
    fullscreenwidth = atoi(tempstr);
 
-   GetPrivateProfileString("Video", "FullScreenHeight", "480", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "FullScreenHeight", "480", tempstr, MAX_PATH, inifilename);
    fullscreenheight = atoi(tempstr);
 
    // Grab Window Settings
-   GetPrivateProfileString("Video", "UseCustomWindowSize", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "UseCustomWindowSize", "0", tempstr, MAX_PATH, inifilename);
    usecustomwindowsize = atoi(tempstr);
 
-   GetPrivateProfileString("Video", "WindowWidth", "320", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "WindowWidth", "320", tempstr, MAX_PATH, inifilename);
    windowwidth = atoi(tempstr);
 
-   GetPrivateProfileString("Video", "WindowHeight", "224", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Video", "WindowHeight", "224", tempstr, MAX_PATH, inifilename);
    windowheight = atoi(tempstr);
 
    // Grab Sound Core Settings
-   GetPrivateProfileString("Sound", "SoundCore", "-1", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Sound", "SoundCore", "-1", tempstr, MAX_PATH, inifilename);
    sndcoretype = atoi(tempstr);
 
    if (sndcoretype == -1)
       sndcoretype = SNDCORE_DIRECTX;
 
    // Grab Volume Settings
-   GetPrivateProfileString("Sound", "Volume", "100", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Sound", "Volume", "100", tempstr, MAX_PATH, inifilename);
    sndvolume = atoi(tempstr);
 
-   GetPrivateProfileString("General", "CartType", "", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "CartType", "", tempstr, MAX_PATH, inifilename);
 
    // Grab Netlink Settings
-   GetPrivateProfileString("Netlink", "LocalRemoteIP", "127.0.0.1", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Netlink", "LocalRemoteIP", "127.0.0.1", tempstr, MAX_PATH, inifilename);
    sscanf(tempstr, "%d.%d.%d.%d", ip, ip+1, ip+2, ip+3);
    netlinklocalremoteip = (DWORD)MAKEIPADDRESS(ip[0], ip[1], ip[2], ip[3]);
 
-   GetPrivateProfileString("Netlink", "Port", "7845", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Netlink", "Port", "7845", tempstr, MAX_PATH, inifilename);
    netlinkport = atoi(tempstr);
 
    sprintf(netlinksetting, "%d.%d.%d.%d\n%d", (int)FIRST_IPADDRESS(netlinklocalremoteip), (int)SECOND_IPADDRESS(netlinklocalremoteip), (int)THIRD_IPADDRESS(netlinklocalremoteip), (int)FOURTH_IPADDRESS(netlinklocalremoteip), netlinkport);
 
 #if DEBUG
    // Grab Logging settings
-   GetPrivateProfileString("Log", "Enable", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Log", "Enable", "0", tempstr, MAX_PATH, inifilename);
    uselog = atoi(tempstr);
 
-   GetPrivateProfileString("Log", "Type", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Log", "Type", "0", tempstr, MAX_PATH, inifilename);
    logtype = atoi(tempstr);
 
-   GetPrivateProfileString("Log", "Filename", "", logfilename, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("Log", "Filename", "", logfilename, MAX_PATH, inifilename);
 
    if (uselog)
    {
@@ -878,9 +937,9 @@ int YuiInit(LPSTR lpCmdLine)
                                   NULL,
                                   (DLGPROC)LogDlgProc);
             GetWindowRect(LogWin, &rect);
-            GetPrivateProfileString("Log", "WindowX", "0", tempstr, MAX_PATH, inifilename);
+            GetPrivateProfileStringA("Log", "WindowX", "0", tempstr, MAX_PATH, inifilename);
             ret = atoi(tempstr);
-            GetPrivateProfileString("Log", "WindowY", "0", tempstr, MAX_PATH, inifilename);
+            GetPrivateProfileStringA("Log", "WindowY", "0", tempstr, MAX_PATH, inifilename);
             SetWindowPos(LogWin, HWND_TOP, ret, atoi(tempstr), rect.right-rect.left, rect.bottom-rect.top, SWP_NOCOPYBITS | SWP_SHOWWINDOW);
             MainLog = DebugInit("main", DEBUG_CALLBACK, (char *)&UpdateLogCallback);
             break;
@@ -891,9 +950,9 @@ int YuiInit(LPSTR lpCmdLine)
 #endif
 
    // Get Window Position(if saved)
-   GetPrivateProfileString("General", "WindowX", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "WindowX", "0", tempstr, MAX_PATH, inifilename);
    yabwinx = atoi(tempstr);
-   GetPrivateProfileString("General", "WindowY", "0", tempstr, MAX_PATH, inifilename);
+   GetPrivateProfileStringA("General", "WindowY", "0", tempstr, MAX_PATH, inifilename);
    yabwiny = atoi(tempstr);
 
 #ifndef NO_CLI
@@ -973,7 +1032,7 @@ int YuiInit(LPSTR lpCmdLine)
    MyWndClass.hIcon = LoadIcon(y_hInstance, MAKEINTRESOURCE(IDI_ICON));
    MyWndClass.hCursor = LoadCursor(NULL, IDC_ARROW);
    MyWndClass.hbrBackground = (HBRUSH) GetStockObject(BLACK_BRUSH);
-   MyWndClass.lpszClassName = "Yabause";
+   MyWndClass.lpszClassName = _16("Yabause");
    MyWndClass.lpszMenuName = NULL;
 
    YabMenu = LoadMenu(y_hInstance, MAKEINTRESOURCE(IDR_MENU));
@@ -984,8 +1043,8 @@ int YuiInit(LPSTR lpCmdLine)
    sprintf(szAppName, "Yabause %s", VERSION);
 
    // Create new window
-   YabWin = CreateWindow("Yabause",            // class
-                         szAppName,            // caption
+   YabWin = CreateWindow(_16("Yabause"),       // class
+                         _16(szAppName),       // caption
                          WS_OVERLAPPED | WS_CAPTION | WS_SYSMENU |                                        
                          WS_THICKFRAME | WS_MINIMIZEBOX |   // style
                          WS_CLIPCHILDREN,
@@ -1035,10 +1094,14 @@ YabauseSetup:
       {
          nocorechange = 1;
 
-         if (DialogBox(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_SETTINGS), YabWin, (DLGPROC)SettingsDlgProc) != TRUE)
+         ret = (int)SettingsCreatePropertySheets(NULL, TRUE, &settingspsp);
+         free(settingspsp.psp);
+         memset(&settingspsp, 0, sizeof(settingspsp));
+
+         if (ret != TRUE)
          {
             // exit program with error
-            MessageBox (NULL, "yabause.ini must be properly setup before program can be used.", "Error",  MB_OK | MB_ICONINFORMATION);
+            MessageBox (NULL, _16("yabause.ini must be properly setup before program can be used."), _16("Error"),  MB_OK | MB_ICONINFORMATION);
             return -1;
          }
 
@@ -1131,9 +1194,9 @@ YabauseSetup:
       DestroyMenu(YabMenu);
 
    sprintf(tempstr, "%d", yabwinx);
-   WritePrivateProfileString("General", "WindowX", tempstr, inifilename);
+   WritePrivateProfileStringA("General", "WindowX", tempstr, inifilename);
    sprintf(tempstr, "%d", yabwiny);
-   WritePrivateProfileString("General", "WindowY", tempstr, inifilename);
+   WritePrivateProfileStringA("General", "WindowY", tempstr, inifilename);
 
    if (argv)
       LocalFree(argv);
@@ -1143,10 +1206,45 @@ YabauseSetup:
 
 //////////////////////////////////////////////////////////////////////////////
 
+void ClearMenuChecks(HMENU hmenu, int startid, int endid)
+{
+   int i;
+
+   for (i = startid; i <= endid; i++)
+      CheckMenuItem(hmenu, i, MF_UNCHECKED);
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+void ChangeLanguage(int id)
+{
+   static char *langfiles[] = {
+      "yabause_de.yts",
+      "yabause_en.yts",
+      "yabause_fr.yts",
+      "yabause_it.yts",
+      "yabause_pt.yts",
+      "yabause_pt_BR.yts",
+      "yabause_es.yts",
+      "yabause_sv.yts"
+   };
+
+   if (langfiles[id-IDM_GERMAN])
+   {
+      if (mini18n_set_locale(langfiles[id-IDM_GERMAN]) == -1)
+         return;
+   }
+
+   ClearMenuChecks(YabMenu, IDM_GERMAN, IDM_SPANISH);
+   CheckMenuItem(YabMenu, id, MF_CHECKED);
+}
+//////////////////////////////////////////////////////////////////////////////
+
 LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
 {
    DIDEVCAPS didc;
    int i;
+   char text[MAX_PATH];
 
    switch (uMsg)
    {
@@ -1167,7 +1265,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
                EnableMenuItem(YabMenu, IDM_RUN, MF_GRAYED);
                EnableMenuItem(YabMenu, IDM_PAUSE, MF_ENABLED);
                break;
-            }
+            }	
             case IDM_PAUSE:
             {
                YuiPause();
@@ -1206,7 +1304,9 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             case IDM_SETTINGS:
             {
                YuiTempPause();
-               DialogBox(y_hInstance, MAKEINTRESOURCE(IDD_SETTINGS), hWnd, (DLGPROC)SettingsDlgProc);
+               SettingsCreatePropertySheets(hWnd, TRUE, &settingspsp);
+               free(settingspsp.psp);
+               memset(&settingspsp, 0, sizeof(settingspsp));
                YuiTempUnPause();
                break;
             }
@@ -1217,6 +1317,16 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
                YuiTempUnPause();
                break;
             }
+            case IDM_GERMAN:
+            case IDM_ENGLISH:
+            case IDM_FRENCH:
+            case IDM_ITALIAN:
+            case IDM_PORTUGUESE:
+            case IDM_PORTUGUESEBRAZIL:
+            case IDM_SPANISH:
+            case IDM_SWEDISH:
+               ChangeLanguage(LOWORD(wParam));
+               break;
             case IDM_MSH2DEBUG:
             {
                YuiTempPause();
@@ -1261,6 +1371,14 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
                YuiTempUnPause();
                break;
             }
+		case ID_RAM_WATCH:
+			if(!RamWatchHWnd)
+			{
+				RamWatchHWnd = CreateDialog(y_hInstance, MAKEINTRESOURCE(IDD_RAMWATCH), hWnd, (DLGPROC) RamWatchProc);
+			}
+			else
+				SetForegroundWindow(RamWatchHWnd);
+			break;
             case IDM_SCSPDEBUG:
             {
                YuiTempPause();
@@ -1330,42 +1448,135 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             }
             case IDM_SAVESTATEAS:
             {
+               WCHAR filter[1024];
                OPENFILENAME ofn;
 
                YuiTempPause();
 
-               SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd,
-                        "Yabause Save State files\0*.YSS\0All Files\0*.*\0",
-                        yssfilename, sizeof(yssfilename));
-               ofn.lpstrDefExt = "YSS";
+               CreateFilter(filter, 1024,
+                  "Yabause Save State files", "*.YSS",
+                  "All files (*.*)", "*.*", NULL);
+
+               SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd, filter,
+                        yssfilename, sizeof(yssfilename)/sizeof(TCHAR));
+               ofn.lpstrDefExt = _16("YSS");
 
                if (GetSaveFileName(&ofn))
                {
-                  if (YabSaveState(yssfilename) != 0)
-                     MessageBox (hWnd, "Couldn't save state file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  WideCharToMultiByte(CP_ACP, 0, yssfilename, -1, text, sizeof(text), NULL, NULL);
+                  if (YabSaveState(text) != 0)
+                     MessageBox (hWnd, _16("Couldn't save state file"), _16("Error"),  MB_OK | MB_ICONINFORMATION);
                }
                YuiTempUnPause();
                break;
             }
             case IDM_LOADSTATEAS:
             {
+               WCHAR filter[1024];
                OPENFILENAME ofn;
 
                YuiTempPause();
 
-               SetupOFN(&ofn, OFN_DEFAULTLOAD, hWnd,
-                        "Yabause Save State files\0*.YSS\0All Files\0*.*\0",
-                        yssfilename, sizeof(yssfilename));
+               CreateFilter(filter, 1024,
+                  "Yabause Save State files", "*.YSS",
+                  "All files (*.*)", "*.*", NULL);
+
+               SetupOFN(&ofn, OFN_DEFAULTLOAD, hWnd, filter,
+                        yssfilename, sizeof(yssfilename)/sizeof(TCHAR));
 
                if (GetOpenFileName(&ofn))
                {
-                  if (YabLoadState(yssfilename) != 0)
-                     MessageBox (hWnd, "Couldn't load state file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  WideCharToMultiByte(CP_ACP, 0, yssfilename, -1, text, sizeof(text), NULL, NULL);
+                  if (YabLoadState(text) != 0)
+                     MessageBox (hWnd, _16("Couldn't load state file"), _16("Error"),  MB_OK | MB_ICONINFORMATION);
                }
                YuiTempUnPause();
 
                break;
             }
+			case IDM_FILE_RECORDAVI:
+				{
+					WCHAR filter[1024];
+					OPENFILENAME ofn;
+
+					YuiTempPause();
+
+					CreateFilter(filter, 1024,
+						"AVI Files *.avi)", "*.avi",
+						"All files (*.*)", "*.*", NULL);
+
+					SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd, filter,
+						avifilename, sizeof(avifilename)/sizeof(TCHAR));
+					ofn.lpstrDefExt = _16("AVI");
+
+					if (GetSaveFileName(&ofn))
+					{
+						WideCharToMultiByte(CP_ACP, 0, avifilename, -1, text, sizeof(text), NULL, NULL);
+
+						DRV_AviBegin(text, hWnd);
+						AVIRecording=1;
+					}
+					YuiTempUnPause();
+					break;
+				}
+			case IDM_FILE_STOPAVI:
+				DRV_AviEnd();
+				AVIRecording=0;
+				break;
+			case MENU_RECORD_MOVIE:
+				{
+			   WCHAR filter[1024];
+               OPENFILENAME ofn;
+
+               YuiTempPause();
+
+               CreateFilter(filter, 1024,
+                  "Yabause Movie file", "*.YMV",
+                  "All files (*.*)", "*.*", NULL);
+
+               SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd, filter,
+                        ymvfilename, sizeof(ymvfilename)/sizeof(TCHAR));
+               ofn.lpstrDefExt = _16("YMV");
+
+               if (GetSaveFileName(&ofn))
+               {
+                  WideCharToMultiByte(CP_ACP, 0, ymvfilename, -1, text, sizeof(text), NULL, NULL);
+               SaveMovie(text);
+               }
+				}
+				break;
+
+			  case MENU_PLAY_MOVIE:
+            {
+               WCHAR filter[1024];
+               OPENFILENAME ofn;
+
+               YuiTempPause();
+
+               CreateFilter(filter, 1024,
+                  "Yabause Movie files", "*.YMV",
+                  "All files (*.*)", "*.*", NULL);
+
+               SetupOFN(&ofn, OFN_DEFAULTLOAD, hWnd, filter,
+                        ymvfilename, sizeof(ymvfilename)/sizeof(TCHAR));
+
+               if (GetOpenFileName(&ofn))
+               {
+                  WideCharToMultiByte(CP_ACP, 0, ymvfilename, -1, text, sizeof(text), NULL, NULL);
+                  PlayMovie(text);
+               }
+               YuiTempUnPause();
+               break;
+            }
+			case MENU_STOP_MOVIE:
+				StopMovie();
+				break;
+			case IDM_TOGGLEREADONLY:
+				MovieToggleReadOnly();
+				break;
+			case IDM_FRAMEADVANCEPAUSE:
+				PauseOrUnpause();
+				break;
             case IDM_SAVESTATE_F2:
             case IDM_SAVESTATE_F3:
             case IDM_SAVESTATE_F4:
@@ -1377,7 +1588,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             case IDM_SAVESTATE_F10:
                YuiTempPause();
                if (YabSaveStateSlot(ysspath, LOWORD(wParam)-IDM_SAVESTATE_F2) != 0)
-                  MessageBox (hWnd, "Couldn't save state file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  MessageBox (hWnd, _16("Couldn't save state file"), _16("Error"),  MB_OK | MB_ICONINFORMATION);
                YuiTempUnPause();
                break;
             case IDM_LOADSTATE_F2:
@@ -1391,23 +1602,29 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             case IDM_LOADSTATE_F10:
                YuiTempPause();
                if (YabLoadStateSlot(ysspath, LOWORD(wParam)-IDM_LOADSTATE_F2) != 0)
-                  MessageBox (hWnd, "Couldn't load state file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  MessageBox (hWnd, _16("Couldn't load state file"), _16("Error"),  MB_OK | MB_ICONINFORMATION);
                YuiTempUnPause();
                break;
             case IDM_CAPTURESCREEN:
             {
+               WCHAR filter[1024];
                OPENFILENAME ofn;
                
                YuiTempPause();
-               SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd,
-                       "Bitmap Files\0*.BMP\0All Files\0*.*\0",
-                       bmpfilename, sizeof(bmpfilename));
-               ofn.lpstrDefExt = "BMP";
+
+               CreateFilter(filter, 1024,
+                  "Bitmap Files", "*.BMP",
+                  "All files (*.*)", "*.*", NULL);
+
+               SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd, filter,
+                       bmpfilename, sizeof(bmpfilename)/sizeof(TCHAR));
+               ofn.lpstrDefExt = _16("BMP");
 
                if (GetSaveFileName(&ofn))
                {
-                  if (YuiCaptureScreen(bmpfilename))
-                     MessageBox (hWnd, "Couldn't save capture file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  WideCharToMultiByte(CP_ACP, 0, bmpfilename, -1, text, sizeof(text), NULL, NULL);
+                  if (YuiCaptureScreen(text))
+                     MessageBox (hWnd, _16("Couldn't save capture file"), _16("Error"),  MB_OK | MB_ICONINFORMATION);
                }
                YuiTempUnPause();
                break;
@@ -1420,27 +1637,27 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             }
             case IDM_WEBSITE:
             {
-               ShellExecute(NULL, "open", "http://yabause.sourceforge.net", NULL, NULL, SW_SHOWNORMAL);
+               ShellExecuteA(NULL, "open", "http://yabause.sourceforge.net", NULL, NULL, SW_SHOWNORMAL);
                break;
             }
             case IDM_FORUM:
             {
-               ShellExecute(NULL, "open", "http://yabause.sourceforge.net/forums/", NULL, NULL, SW_SHOWNORMAL);
+               ShellExecuteA(NULL, "open", "http://yabause.sourceforge.net/forums/", NULL, NULL, SW_SHOWNORMAL);
                break;
             }
             case IDM_SUBMITBUGREPORT:
             {
-               ShellExecute(NULL, "open", "http://sourceforge.net/tracker/?func=add&group_id=89991&atid=592126", NULL, NULL, SW_SHOWNORMAL);
+               ShellExecuteA(NULL, "open", "http://sourceforge.net/tracker/?func=add&group_id=89991&atid=592126", NULL, NULL, SW_SHOWNORMAL);
                break;
             }
             case IDM_DONATE:
             {
-               ShellExecute(NULL, "open", "https://sourceforge.net/donate/index.php?group_id=89991", NULL, NULL, SW_SHOWNORMAL);
+               ShellExecuteA(NULL, "open", "https://sourceforge.net/donate/index.php?group_id=89991", NULL, NULL, SW_SHOWNORMAL);
                break;
             }
             case IDM_COMPATLIST:
             {
-               ShellExecute(NULL, "open", "http://www.emu-compatibility.com/yabause/index.php?lang=uk", NULL, NULL, SW_SHOWNORMAL);
+               ShellExecuteA(NULL, "open", "http://www.emu-compatibility.com/yabause/index.php?lang=uk", NULL, NULL, SW_SHOWNORMAL);
                break;
             }
             case IDM_ABOUT:
@@ -1557,7 +1774,7 @@ LRESULT CALLBACK AboutDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
    {
       case WM_INITDIALOG:
          sprintf(tempstr, "Yabause v%s", VERSION);
-         SetDlgItemText(hDlg, IDC_VERSIONTEXT, tempstr);
+         SetDlgItemText(hDlg, IDC_VERSIONTEXT, _16(tempstr));
          return TRUE;
       case WM_COMMAND:
       {
@@ -1590,6 +1807,10 @@ LRESULT CALLBACK AboutDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
 int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpCmdLine, int nCmdShow)
 {
+#ifdef HAVE_LIBMINI18N
+   mini18n_set_domain("trans");
+#endif
+
    if (YuiInit(lpCmdLine) != 0)
       fprintf(stderr, "Error running Yabause\n");
 
@@ -1605,9 +1826,9 @@ int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
       // Remember log window position
       GetWindowRect(LogWin, &rect);
       sprintf(text, "%ld", rect.left);
-      WritePrivateProfileString("Log", "WindowX", text, inifilename);
+      WritePrivateProfileStringA("Log", "WindowX", text, inifilename);
       sprintf(text, "%ld", rect.top);
-      WritePrivateProfileString("Log", "WindowY", text, inifilename);
+      WritePrivateProfileStringA("Log", "WindowY", text, inifilename);
 
       DestroyWindow(LogWin);
    }
