@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <sys/types.h>
@@ -40,6 +40,7 @@
 #include "vdp2.h"
 #include "yui.h"
 #include "bios.h"
+#include "movie.h"
 #ifdef HAVE_LIBSDL
  #ifdef __APPLE__
   #include <SDL/SDL.h>
@@ -47,7 +48,7 @@
   #include "SDL.h"
  #endif
 #endif
-#ifdef _MSC_VER
+#if defined(_MSC_VER) || !defined(HAVE_SYS_TIME_H)
 #include <time.h>
 #else
 #include <sys/time.h>
@@ -59,9 +60,16 @@
 #include <ogc/lwp_watchdog.h>
 extern long long gettime();
 #endif
+#ifdef PSP
+#include "psp/common.h"
+#endif
 
-#define DONT_PROFILE
-#include "profile.h"
+#ifdef SYS_PROFILE_H
+ #include SYS_PROFILE_H
+#else
+ #define DONT_PROFILE
+ #include "profile.h"
+#endif
 
 //////////////////////////////////////////////////////////////////////////////
 
@@ -347,24 +355,93 @@ void YabauseResetButton(void) {
 //////////////////////////////////////////////////////////////////////////////
 
 int YabauseExec(void) {
+
+	//automatically advance lag frames, this should be optional later
+	if (FrameAdvanceVariable > 0 && LagFrameFlag == 1){ 
+		FrameAdvanceVariable = NeedAdvance; //advance a frame
+		YabauseEmulate();
+		FrameAdvanceVariable = Paused; //pause next time
+		return(0);
+	}
+
+	if (FrameAdvanceVariable == Paused){
+		ScspMuteAudio();
+		return(0);
+	}
+  
+	if (FrameAdvanceVariable == NeedAdvance){  //advance a frame
+		FrameAdvanceVariable = Paused; //pause next time
+		ScspUnMuteAudio();
+		YabauseEmulate();
+	}
+	
+	if (FrameAdvanceVariable == RunNormal ) { //run normally
+		ScspUnMuteAudio();	
+		YabauseEmulate();
+	}
+	return 0;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+int YabauseEmulate(void) {
+   int M68k_cycles;              // Integral M68k cycles to execute this time
+   static int M68k_centicycles;  // Fractional cycle counter for M68k
+
    int oneframeexec=0;
 
+   DoMovie();
+
    while (!oneframeexec)
    {
+#ifdef NO_DECILINE
+      const unsigned int sh2cycles = yabsys.DecilineStop * 10;
+#else
+      const unsigned int sh2cycles = yabsys.DecilineStop;
+#endif
+
       PROFILE_START("Total Emulation");
+
+#ifdef NO_DECILINE
+
+      PROFILE_START("MSH2");
+      SH2Exec(MSH2, sh2cycles - yabsys.DecilineStop);
+      PROFILE_STOP("MSH2");
+      PROFILE_START("SSH2");
+      if (yabsys.IsSSH2Running)
+         SH2Exec(SSH2, sh2cycles - yabsys.DecilineStop);
+      PROFILE_STOP("SSH2");
+
+      PROFILE_START("hblankin");
+      Vdp2HBlankIN();
+      PROFILE_STOP("hblankin");
+
       PROFILE_START("MSH2");
       SH2Exec(MSH2, yabsys.DecilineStop);
       PROFILE_STOP("MSH2");
-
       PROFILE_START("SSH2");
       if (yabsys.IsSSH2Running)
          SH2Exec(SSH2, yabsys.DecilineStop);
       PROFILE_STOP("SSH2");
 
+#else // !NO_DECILINE
+
+      PROFILE_START("MSH2");
+      SH2Exec(MSH2, sh2cycles);
+      PROFILE_STOP("MSH2");
+
+      PROFILE_START("SSH2");
+      if (yabsys.IsSSH2Running)
+         SH2Exec(SSH2, sh2cycles);
+      PROFILE_STOP("SSH2");
+
+#endif
+
       PROFILE_START("SCU");
-      ScuExec(yabsys.DecilineStop >> 1);
+      ScuExec(sh2cycles / 2);
       PROFILE_STOP("SCU");
 
+#ifndef NO_DECILINE
       yabsys.DecilineCount++;
       if(yabsys.DecilineCount == 9)
       {
@@ -374,6 +451,7 @@ int YabauseExec(void) {
          PROFILE_STOP("hblankin");
       }
       else if (yabsys.DecilineCount == 10)
+#endif
       {
          // HBlankOUT
          PROFILE_START("hblankout");
@@ -404,26 +482,69 @@ int YabauseExec(void) {
          }
       }
 
-      yabsys.CycleCountII += MSH2->cycles;
+#ifdef PSP_TIMING_TWEAKS
+      yabsys.CycleCountII += sh2cycles;
+#else
+      yabsys.CycleCountII += sh2cycles + MSH2->cycles;
+#endif
 
-      while (yabsys.CycleCountII > yabsys.Duf)
       {
-         PROFILE_START("SMPC");
-         SmpcExec(10);
-         PROFILE_STOP("SMPC");
-         PROFILE_START("CDB");
-         Cs2Exec(10);
-         PROFILE_STOP("CDB");
-         yabsys.CycleCountII %= yabsys.Duf;
+         u32 usec = 0;
+         while (yabsys.CycleCountII > yabsys.Duf)
+         {
+             yabsys.CycleCountII -= yabsys.Duf;
+             usec += 10;
+         }
+         if (usec > 0)
+         {
+            PROFILE_START("SMPC");
+            SmpcExec(usec);
+            PROFILE_STOP("SMPC");
+            PROFILE_START("CDB");
+            Cs2Exec(usec);
+            PROFILE_STOP("CDB");
+         }
       }
 
       PROFILE_START("68K");
-      M68KExec(170);
+#ifdef NO_DECILINE
+      if (yabsys.IsPal)
+      {
+         /* 11.2896MHz / 50Hz / 262.5 lines / 10 calls/line = 86.01 cycles/call */
+         M68k_cycles = 860;
+         M68k_centicycles += 10;
+      }
+      else
+      {
+         /* 11.2896MHz / 60Hz / 262.5 lines / 10 calls/line = 71.68 cycles/call */
+         M68k_cycles = 716;
+         M68k_centicycles += 80;
+      }
+      if (M68k_centicycles >= 100) {
+         M68k_cycles++;
+         M68k_centicycles -= 100;
+      }
+#else
+      if (yabsys.IsPal)
+      {
+         /* 11.2896MHz / 50Hz / 262.5 lines / 10 calls/line = 86.01 cycles/call */
+         M68k_cycles = 86;
+         M68k_centicycles += 1;
+      }
+      else
+      {
+         /* 11.2896MHz / 60Hz / 262.5 lines / 10 calls/line = 71.68 cycles/call */
+         M68k_cycles = 71;
+         M68k_centicycles += 68;
+      }
+      if (M68k_centicycles >= 100) {
+         M68k_cycles++;
+         M68k_centicycles -= 100;
+      }
+#endif
+      M68KExec(M68k_cycles);
       PROFILE_STOP("68K");
 
-      MSH2->cycles %= yabsys.DecilineStop;
-      if (yabsys.IsSSH2Running) 
-         SSH2->cycles %= yabsys.DecilineStop;
       PROFILE_STOP("Total Emulation");
    }
    return 0;
@@ -458,16 +579,18 @@ u64 YabauseGetTicks(void) {
    u64 ticks;
    QueryPerformanceCounter((LARGE_INTEGER *)&ticks);
    return ticks;
-#elif defined(HAVE_LIBSDL)
-   return SDL_GetTicks();
 #elif defined(_arch_dreamcast)
    return (u64) timer_ms_gettime64();
-#elif defined(__APPLE__)
-   struct timeval Time;
-   gettimeofday(&Time, NULL);
-   return (u64)(Time.tv_usec/1000);
 #elif defined(GEKKO)  
    return gettime();
+#elif defined(PSP)
+   return sceKernelGetSystemTimeWide();
+#elif defined(HAVE_GETTIMEOFDAY)
+   struct timeval tv;
+   gettimeofday(&tv, NULL);
+   return (u64)tv.tv_sec * 1000000 + tv.tv_usec;
+#elif defined(HAVE_LIBSDL)
+   return (u64)SDL_GetTicks();
 #endif
 }
 
@@ -478,9 +601,15 @@ void YabauseSetVideoFormat(int type) {
    yabsys.MaxLineCount = type ? 313 : 263;
 #ifdef WIN32
    QueryPerformanceFrequency((LARGE_INTEGER *)&yabsys.tickfreq);
-#elif defined(GEKKO)  
+#elif defined(_arch_dreamcast)
+   yabsys.tickfreq = 1000;
+#elif defined(GEKKO)
    yabsys.tickfreq = secs_to_ticks(1);
-#else
+#elif defined(PSP)
+   yabsys.tickfreq = 1000000;
+#elif defined(HAVE_GETTIMEOFDAY)
+   yabsys.tickfreq = 1000000;
+#elif defined(HAVE_LIBSDL)
    yabsys.tickfreq = 1000;
 #endif
    yabsys.OneFrameTime = yabsys.tickfreq / (type ? 50 : 60);
@@ -788,4 +917,4 @@ int YabauseQuickLoadGame(void)
    return 0;
 }
 
-//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
\ No newline at end of file
