@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifndef YABAUSE_H
@@ -89,4 +89,10 @@ typedef struct
 
 extern yabsys_struct yabsys;
 
+/* Functions that need to be defined by the port: */
+extern void YuiErrorMsg(const char *string);
+extern void YuiSwapBuffers(void);
+
+int YabauseEmulate(void);
+
 #endif
