@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #ifdef HAVE_LIBGL
@@ -225,6 +225,11 @@ int * YglQuad(YglSprite * input, YglTexture * output) {
    YglLevel *level;
    texturecoordinate_struct *tmp;
 
+   if (input->priority > 7) {
+      VDP1LOG("sprite with priority %d\n", input->priority);
+      return NULL;
+   }
+
    level = &_Ygl->levels[input->priority];
 
    if (level->currentQuad == level->maxQuad) {
